#!/usr/bin/env python
#Usage: $0 uni0E01 > code.txt
#or:    $0 --all

import os
import sys
import dfont

# cvt value
#NEW VALUE ***
#    "headdia":          257,    #384
#    "headstem":         258,    #120
#    "hwidth_14":        256,    #896    =ko_kai
cvt_dict = {
    "w_1001":           71,     #1001   =
    "w_938":            78,     #938    =
    "w_918":            231,    #918    =
    "w_896":            256,    #896    =
    "w_905":            209,    #905    =lo_ling
    "w_881":            163,    #881    =
    "w_864":            173,    #864    =jo_jan
    "w_852":            116,    #852    =
    "w_836":            247,    #836    =
    "w_821":            224,    #821    =
    "w_819":            72,     #819    =
    "w_772":            108,    #772    =no_nu
    "w_758":            245,    #758    =
    "w_720":            262,    #720    =
    "w_690":            14,     #690    =
    "w_530":            64,     #530    =
    "w_451":            157,    #451    =
    "w_340":            38,     #340    =
    "w_309":            0,      #309    =
    "w_307":            57,     #307
    "w_193":            4,      #193    =
    "w_106":            225,    #106    =
    "w_102":            9,      #102    =
    "w_84":             148,    #84
    "w_60":             260,    #60
#
    "base":             10,     #0
    "hstem":            8,      #184
    "hstem_curve":      18,     #195    =big curve hstem
#
    "vstem":            169,    #143    =straight vstem
    "vstem_curve":      185,    #156    =curve vstem
    "vstem":            96,     #154 
    "vstem_small":      27,     #135 
    "vstem_tiny":       9,      #102 
    "vstem_thick":      130,    #266 
    "headstem":         258,    #116
    "headstem_plus_hole":   259, #268
    "headstem_small":   11,     #113    =kho
    "headstem_small_plus_hole":   130,     #266    =kho
    "headstem_tiny":    148,    #84
    "headstem_wan":     260,    #60
    "sarastem":         90,     #127
#
    "headdia":          257,    #384
    "headdia_small":    180,    #377    =kho
    "headdia_plus":     261,    #442 
    "headdia_full":     157,    #451 
    "headdia_tiny":     0,      #309
    "headhole":         107,    #152    
    "headneck_kho":     39,     #180    =kho
#
    "hwidth_1":         78,     #938    =
    "hwidth_khai":      14,     #690    =kho_khai, cho_ching
    "hwidth_2":         71,     #1001   =kho_kwai
    "hwidth_3":         231,    #918    =th_tung, do_chada, no_nane
    "hwidth_4":         108,    #772    =no_nu
    "hwidth_5":         209,    #905    =lo_ling
    "hwidth_6":         58,     #930    =so_sua
    "hwidth_7":         164,    #987    =po_pung, fo_fa
    "hwidth_8":         73,     #956    =po_pan, fo_fun
    "hwidth_9":         141,    #813    =sara_aa
    "hwidth_10":        116,    #852    =wo_wan
    "hwidth_11":        245,    #758    =ngo_ngu, sara_aae, mo_ma, to_thong
    "hwidth_12":        163,    #881    =ko_kai, do_chada
    "hwidth_13":        173,    #864    =jo_jan
    "hwidth_14":        256,    #896    =
#
    "hnext_1":          111,    #469    =next spline of sho_sher
    "hnext_2":          68,     #479    =next spline of yo_ying
#
    "vheight":          188,    #1120   =normal height 
    "vheight_shoot":    184,    #1147   =overshoot height
    "vheight_hi":       49,     #1208   =ko 
    "vheight_hi_kho":   47,     #1204   =kho 
    "vheight_po":       151,    #1556   =po_pla, fo_fa
    "vheight_o":        179,    #1638   =sara_o, sara_i
    "vheight_lo":       140,    #29 
    "vheight_lu":       176,    #410    =lo_lu
    "vheight_below_do": 176,    #410
    "vheight_num":      209,    #905
    "vheight_sara1":    250,    #1262
#
    "head_diff":        131,    #254    =head of character: bo,po
    "beak_diff":        148,    #84     =beak of ko,tho
    "beak_diff_2":      38,     #340    =beak of ko,tho
#
    "front_001":        25,     #211    =front spacing of tho
    "front_kai":        11,     #113    =front spacing of ko_kai
    "front_khai":       32,     #51     =front spacing of kho_khai, do_chada, cho_ching
    "front_pung":       85,     #164
    "front_e":          131,    #254    =front spaceing of sara_e
#
    "front_khuad":      157,    #451    =front spacing of kho_khud
    "front_kwai":       100,    #205    =front spacing of kho_kwai, yo_yak
    "front_dek":        96,     #154    =front spaceing of do_dek
    "front_thong":      79,     #229    =front spaceing of to_thong
    "front_pung":       228,    #174    =front spaceing of po_pung
    "front_pan":        31,     #330    =front spacing of do_chada, po_pan
    "front_ma":         180,    #377    =front spaceing of mo_ma
    "front_ling":       1,      #184    =front spaceing of lo_ling, aw_ang
#
#special
    "special_1":        230,    #45
    "special_2":        88,     #20
}

######### PSUEDO-CODE ##########
pseudo_code_dict = {
    #ko_kai
    "uni0E01": """
srp0    26
mirp[rp0,min,rnd,grey]  front_kai 18
mdrp[min,rnd,grey]  8
mdrp[rp0,rnd,grey]  10
mdrp[min,rnd,grey]  17
srp0    18
mdrp[rp0,rnd,grey]  14
mirp[min,rnd,grey]  hstem  12
srp2    12
mirp[rp0,rnd,grey]  w_881 25
mdrp[rnd,white] 27
mirp[min,rnd,grey]  hstem  1
IUP[x]
SVTCA[y-axis]
mdap[rnd]  1
alignrp    13
mirp[rp0,rnd,grey]  vheight_shoot    22
mirp[min,rnd,grey]  vstem_curve  5
srp1    5
srp2    13
sloop   10
ip  19 8 18 9 17 10 2 25 15 12
IUP[y]
""",

    #kho_khai
    "uni0E02":  """
srp0    53
mirp[rp0,min,rnd,grey]  front_khai 21
mirp[min,rnd,grey]  headstem 50
mirp[rp0,rnd,grey]  headdia 15
mdrp[rnd,grey]  12
mirp[min,rnd,grey]  headstem 44
mdrp[rp0,rnd,white] 7
mirp[rp0,rnd,grey] vstem 27
mdrp[rp0,rnd,white]  36
mirp[rp0,min,rnd,grey] hstem 38
mdrp[rnd,white] 54
mirp[rp0,rnd,grey]  hwidth_khai 1
mirp[min,rnd,grey]  hstem 32
IUP[x]
SVTCA[y-axis]
mdap[rnd]   1
mirp[rnd,grey]      vheight 38
mirp[min,rnd,grey]  vstem 33
mirp[rp0,rnd,grey]  vheight_shoot 24
mirp[rp0,rnd,grey]  headstem 10
mdrp[rp0,rnd,white] 12
mdrp[rp0,rnd,grey]  18
mirp[min,rnd,grey]  headstem 41
mirp[rnd,grey]  headstem_plus_hole 47
IUP[y]
""",

    #kho_khuad
    "uni0E03": """
srp0    57
mirp[rp0,min,rnd,grey] front_khai 24
mdrp[min,rnd,grey]  13
mdrp[rp0,rnd,grey]  18
mirp[min,rnd,grey]  headstem 48
mirp[rnd,grey]  headstem_plus_hole 54
srp0    24
mdrp[rp0,rnd,grey]  31
mirp[min,rnd,grey]  vstem 7
srp1    13
sloop   6
ip  27 11 28 10 29 9
mdrp[rp0,rnd,white] 40
mirp[rp0,min,rnd,grey]  hstem 42
mdrp[rnd,white] 58
mirp[rp0,rnd,grey]  w_690 1
mirp[min,rnd,grey]  hstem 36
IUP[x]
SVTCA[y-axis]
mdap[rnd]  1
mirp[min,rnd,grey]  vstem   37
mirp[rnd,grey]  vheight 42
mirp[rp0,rnd,grey]  vheight_shoot   27
alignrp     29
mirp[min,rnd,grey]  sarastem 11
shp[rp2]    9
mdrp[rp0,min,rnd,grey]  28
mirp[rp0,min,rnd,grey]  hstem_curve 10
mdrp[rp0,rnd,white] 15
mdrp[rnd,grey]  13
mirp[min,rnd,grey]  headstem 51
mirp[rp0,rnd,grey]  headdia 21
mirp[min,rnd,grey]  headstem 45
IUP[y]
""",

    #kho_kwai
    "uni0E04": """
srp0    52
mirp[rp0,min,rnd,grey] front_kai 33
mirp[min,rnd,grey]  hstem 8
mirp[rp0,rnd,grey]  w_1001  39
mdrp[rnd,white] 53
mirp[min,rnd,grey]  hstem 1
srp0    8
mdrp[rp0,rnd,white] 11
mdrp[min,rnd,grey]  27
mdrp[rp0,rnd,grey]  30
mirp[min,rnd,grey]  hstem 29
srp0    11
mdrp[rp0,rnd,white] 14
mdrp[min,rnd,grey]  25
srp0    33
mirp[rp0,rnd,grey]  w_690   20
mirp[min,rnd,grey]  headstem 43
mirp[rnd,grey]  headstem_plus_hole 49
IUP[x]                              ;Interpolate Untouched Points through the outline
SVTCA[y-axis]                       ;Set freedom and projection Vectors To Coordinate Axis
MDAP[rnd]                0          ;Move Direct Absolute Point
ALIGNRP                  29         ;ALIGN to Reference Point
MIRP[rp0,rnd,grey]       vheight_shoot  36     ;Move Indirect Relative Point
MIRP[min,rnd,grey]       vstem_curve  5      ;Move Indirect Relative Point
MDRP[rp0,rnd,grey]       17         ;Move Direct Relative Point
MIRP[min,rnd,grey]       headstem  46    ;Move Indirect Relative Point
MIRP[rp0,rnd,grey]       headdia  23    ;Move Indirect Relative Point
MIRP[min,rnd,grey]       headstem  40    ;Move Indirect Relative Point
srp0    29
mdrp[min,rnd,grey]  11
srp1    5
srp2    11
sloop 4
ip 33 8 2 39
IUP[y]                              ;Interpolate Untouched Points through the out
""",

    #kho_kon
    "uni0E05": """
srp0    55
mirp[rp0,min,rnd,grey] front_kai 34
mirp[min,rnd,grey]  hstem 9
mirp[rp0,rnd,grey]  w_1001  42
sloop 7
ip 37 7 38 6 5 39 4
mdrp[rnd,white] 56
mirp[min,rnd,grey]  hstem 1
srp0    9
mdrp[rp0,rnd,white] 12
mdrp[min,rnd,grey]  28
mdrp[rp0,rnd,grey]  31
mirp[min,rnd,grey]  hstem 30
srp0    12
mdrp[rp0,rnd,white] 15
mdrp[min,rnd,grey]  25
srp0    34
mirp[rp0,rnd,grey]  w_690   21
mirp[min,rnd,grey]  headstem 46
mirp[rnd,grey]  headstem_plus_hole 52
IUP[x]
SVTCA[y-axis]
mdap[rnd]   1
alignrp 30
mirp[rp0,rnd,grey]  vheight_shoot 39
alignrp 37
mirp[min,rnd,grey]  vstem_curve 4
shp[rp2]    7
mdrp[rp0,min,rnd,grey]  5
mirp[min,rnd,grey]  headstem 38
mdrp[rp0,rnd,white]  18
mirp[min,rnd,grey]  headstem 49
mirp[rp0,rnd,grey]  headdia 24
mirp[min,rnd,grey]  headstem 43
mdrp[min,rnd,grey]  26
srp0    30
mdrp[min,rnd,grey]  12
srp1    5
srp2    12
sloop   4
ip  34  9   2   42
IUP[y]
""",

    #kho_rakang
    "uni0E06": """
srp0    79
mirp[rp0,min,rnd,grey]  front_khai 37
mdrp[min,rnd,grey]  26
mdrp[rp0,rnd,grey]  31
mirp[min,rnd,grey]  headstem 58
mirp[rnd,grey]  headstem_plus_hole 64
srp0    37
mdrp[rp0,rnd,grey]  44
mirp[min,rnd,grey]  vstem 20
srp1    26
sloop   6
ip  40 24 41 23 42 22
mdrp[rp0,rnd,white] 52
alignrp 1
mirp[rp0,min,rnd,grey]  hstem 54
mdrp[rnd,white] 80
mirp[rp0,rnd,grey]  w_758 14
mirp[min,rnd,grey]  hstem 49
shp[rp2]  3
mdrp[rp0,rnd,grey]  9
mirp[min,rnd,grey]  headstem 76
mirp[rnd,grey]  headstem_plus_hole 70
IUP[x]
SVTCA[y-axis]
mdap[rnd]   1
mirp[min,rnd,grey]  vstem 52
mirp[rnd,grey]  vheight_lo  6
mirp[rnd,grey]  vheight 53
mirp[rp0,rnd,grey]  vheight_shoot 40
alignrp 42
mirp[min,rnd,grey]  sarastem 24
shp[rp2]    22
mdrp[rp0,min,rnd,grey]  41
mirp[rp0,min,rnd,grey]  headstem 23
mdrp[rp0,rnd,white]  28
mirp[min,rnd,grey]  headstem 61
mirp[rp0,rnd,grey]  headdia 34
mirp[min,rnd,grey]  headstem 55
srp0    6
mdrp[rnd,grey]  3
mdrp[rnd,grey]  50
mdrp[rp0,rnd,grey]  12
mirp[min,rnd,grey]  headstem 73
mirp[rnd,grey]  headstem_plus_hole 67
IUP[y]
""",

    #ngo_ngu
    "uni0E07": """
srp0    32
mirp[rp0,min,rnd,grey]  front_khai 4
mdrp[rnd,grey]  5
mirp[rp0,rnd,grey]  hwidth_11   19
mdrp[rnd,white] 33
mirp[min,rnd,grey]  hstem 8
srp1    5
sloop 4
ip  6 3 7 2
mirp[rp0,rnd,grey]  headdia_plus 14
mirp[min,rnd,grey]  headstem 29
mirp[rnd,grey]  headstem_plus_hole 23
IUP[x]
SVTCA[y-axis]
mdap[rnd]   1
mdrp[min,rnd,grey]  8
mirp[rp0,rnd,grey]  vheight_shoot 17
mirp[min,rnd,grey]  headstem 26
mirp[rp0,rnd,grey]  headdia 11
mirp[min,rnd,grey]  headstem 20
srp1    11
srp2    1
sloop   3
ip      5 4 8
IUP[y]
""",

    #jo_jan
    "uni0E08": """
srp0    44
mirp[rp0,min,rnd,grey] front_kai 22
mirp[rp0,rnd,grey]  w_864 29
mdrp[rnd,white] 45
mirp[min,rnd,grey]  hstem 16
mirp[rp0,rnd,grey]  w_307 13
ip  0
srp0 0
mirp[min,rnd,grey]  hstem 1
srp1    1
srp2    22
ip  7
mdap[rnd]    7
mirp[min,rnd,grey]  headstem 41
mirp[rnd,grey]  headstem_plus_hole 35
mdrp[rnd,grey]  12
ip  2
IUP[x]
SVTCA[y-axis]
mdap[rnd]  1
mirp[min,rnd,grey]  vstem 13
mirp[rp0,rnd,grey]  vheight_shoot 26
mirp[min,rnd,grey]  vstem_curve 19
mdrp[rp0,rnd,grey]  10
mirp[min,rnd,grey]  headstem 38
mirp[rp0,rnd,grey]  headdia 4
mirp[min,rnd,grey]  headstem 32
IUP[y]
""",

    #cho_ching
    "uni0E09": """
srp0    67
mirp[rp0,min,rnd,grey] front_khai 7
mdrp[rnd,grey]  22
mirp[min,rnd,grey]  headstem 52
mirp[rnd,grey]  headstem_plus_hole 46
mirp[rp0,rnd,grey]  headdia_plus 12
mirp[rp0,min,rnd,grey]  hstem 1
SHP[rp2]    0
mirp[rp0,rnd,grey]  w_720 29
mirp[min,rnd,grey]  hstem 15
srp0    0
mdrp[rp0,rnd,grey]  41
mdrp[rp0,rnd,grey]  39
mirp[min,rnd,grey]  headstem 64
mirp[rp0,min,rnd,grey]  headdia 33
mirp[min,rnd,grey]  headstem 58
IUP[x]
SVTCA[y-axis]
mdap[rnd]   1
mirp[min,rnd,grey]  vstem_curve 13
mirp[rnd,grey]      vheight_lo  36
mirp[rp0,rnd,grey]  vheight_shoot  26
mirp[rp0,min,rnd,grey]  vstem_curve 19
mdrp[rp0,rnd,white]  10
mirp[min,rnd,grey]  headstem 49
mirp[rp0,rnd,grey]  headdia 4
mirp[min,rnd,grey]  headstem 43
srp0    36
mirp[min,rnd,grey]  headstem 55
mdrp[rp0,rnd,grey]  30
mirp[min,rnd,grey]  headstem 61
srp0    36
mdrp[rp0,rnd,grey]  15
mirp[min,rnd,grey]  vstem_curve 41
srp1    19
sloop   3
ip  16 29 12
IUP[y]
""",

    #cho_chang
    "uni0E0A": """
srp0    62
mirp[rp0,min,rnd,grey]  front_khai 21
mirp[min,rnd,grey]  headstem 59
mirp[rp0,rnd,grey]  headdia 15
mdrp[rnd,grey]  12
mirp[min,rnd,grey]  headstem 53
mdrp[rp0,rnd,white] 7
mirp[rp0,min,rnd,grey]  vstem 27
mdrp[rp0,rnd,white]  36
ip  39
mirp[rp0,min,rnd,grey] hstem 47
ip 45
mdrp[rnd,grey]  43
mirp[rp0,rnd,grey]  w_690 1
mirp[min,rnd,grey]  hstem 32
srp0    43
mirp[min,rnd,grey]  hstem 42
mdrp[rnd,white] 63
IUP[x]
SVTCA[y-axis]
mdap[rnd]   1
mirp[rnd,grey]      vheight_sara1 43
mirp[min,rnd,grey]  vstem 33
mirp[rp0,rnd,grey]  vheight_shoot 24
mirp[rp0,rnd,grey]  headstem 10
mdrp[rp0,rnd,white]     12
mdrp[rp0,rnd,grey]  18
mirp[min,rnd,grey]  headstem 50
mirp[rnd,grey]  headstem_plus_hole 56
IUP[y]
""",

    #so_zo
    "uni0E0B": """
srp0    66
mirp[rp0,min,rnd,grey] front_khai 24
mdrp[min,rnd,grey]  13
mdrp[rp0,rnd,grey]  18
mirp[min,rnd,grey]  headstem 57
mirp[rnd,grey]  headstem_plus_hole 63
srp0    24
mdrp[rp0,rnd,grey]  31
mirp[min,rnd,grey]  vstem_curve 7
srp1    13
sloop   6
ip  27 11 28 10 29 9
mdrp[rp0,rnd,white] 40
ip  43
mirp[rp0,min,rnd,grey]  hstem 51
ip  49
mdrp[rnd,grey]  47
mirp[rp0,rnd,grey]  w_690 1
mirp[min,rnd,grey]  hstem 36
srp0    47
mirp[min,rnd,grey]  hstem 46
mdrp[rnd,white] 67
IUP[x]
SVTCA[y-axis]
mdap[rnd]  1
mirp[min,rnd,grey]  vstem  37
mirp[rnd,grey]  vheight_sara1 47
mirp[rp0,rnd,grey]  vheight_shoot   27
alignrp     29
mirp[min,rnd,grey]  sarastem 11
shp[rp2]    9
mdrp[rp0,min,rnd,grey]  28
mirp[rp0,min,rnd,grey]  headstem 10
mdrp[rp0,rnd,white] 15
mdrp[min,rnd,grey]  13
mirp[min,rnd,grey]  headstem 60
mirp[rp0,rnd,grey]  headdia 21
mirp[min,rnd,grey]  headstem 54
IUP[y]
""",

    #sho_sher
    "uni0E0C": """
srp0    77
mirp[rp0,min,rnd,grey] front_kai 40
mdrp[min,rnd,grey]  21
mdrp[rp0,rnd,grey]  23
mdrp[min,rnd,grey]  39
srp0    40
mdrp[rp0,rnd,grey]  36
mirp[min,rnd,grey]  hstem 25
mirp[rp0,rnd,grey]  w_938 47
mirp[min,rnd,grey]  hstem 14
mirp[rp0,rnd,grey]  hnext_1 52
mirp[min,rnd,grey]  hstem 50
shp[rp2]    1
srp0    36
mirp[rp0,rnd,grey]  headdia_plus 31
mirp[min,rnd,grey]  headstem 56
mirp[rnd,grey]  headstem_plus_hole 62 
mdrp[rp0,rnd,white] 11
mirp[min,rnd,grey]  headstem 74
mirp[rp0,rnd,white] headdia 5
mirp[min,rnd,grey]  headstem 68
IUP[x]
SVTCA[y-axis]
mdap[rnd]  1
mirp[rnd,grey]  vheight_lo  8
shp[rp2]    34
mirp[rnd,grey]  vheight 52
mirp[min,rnd,grey]  vstem_curve 50
mirp[rp0,rnd,grey]  vheight_shoot 44
mirp[min,rnd,grey]  vstem_curve 18
srp0    8
mirp[min,rnd,grey] headstem 65
shp[rp2] 53
mirp[rp0,rnd,grey] headdia 14
alignrp 28
mirp[min,rnd,grey]  headstem 71
shp[rp2] 59
mdrp[rnd,grey]  48
mdrp[min,rnd,grey]  3
srp1    18
sloop   10
ip  41 21 40 22 39 23 15 47 37 25
IUP[y]
""",

    #yo_ying
    "uni0E0D": """
srp0    82
mirp[rp0,min,rnd,grey] front_kai 27
mdrp[min,rnd,grey]  8
mdrp[rp0,rnd,grey]  10
mdrp[min,rnd,grey]  26
srp0    27
mdrp[rp0,rnd,grey]  23
mirp[min,rnd,grey]  hstem 12
mirp[rp0,rnd,grey]  w_881 34
mirp[min,rnd,grey]  hstem 1
mirp[rp0,rnd,grey]  hnext_2  38
mdrp[rnd,grey]  67
mirp[min,rnd,grey]  hstem 36
srp0    23
mirp[rp0,rnd,grey]  headdia_plus 18
mirp[min,rnd,grey]  headstem 42
mirp[rnd,grey]  headstem_plus_hole 48
srp0    1
mdrp[rp0,rnd,grey]  54
mdrp[min,rnd,grey]  79
mdrp[rp0,rnd,grey]  60
mdrp[min,rnd,grey]  73
mdrp[rnd,grey]  62
IUP[x]
SVTCA[y-axis]
mdap[rnd]  1
mirp[rnd,grey]  vheight_lo 21
mirp[rnd,grey]  vheight 38
mirp[min,rnd,grey]  vstem 35
mirp[rp0,rnd,grey]  vheight_shoot 31
mirp[min,rnd,grey]  vstem_curve 5
srp0    21
mirp[min,rnd,grey] headstem 39
mirp[rp0,rnd,grey] headdia 15
mirp[min,rnd,grey]  headstem 45
srp0    1
mdrp[rp0,min,rnd,grey] 57
mdrp[min,rnd,grey]  76
mdrp[rp0,rnd,grey]  51
mdrp[min,rnd,grey]  70
mdrp[min,rnd,grey]  62
mdrp[rp0,rnd,grey]  67
mdrp[min,rnd,grey]  66
srp1    5
srp2    1
sloop   10
ip  28 8 27 9 26 10 2 34 24 12
IUP[y]
""",

    #yo_ying
    "uni0E0D.descless": """
srp0    51
mirp[rp0,min,rnd,grey] front_kai 27
mdrp[min,rnd,grey]  8
mdrp[rp0,rnd,grey]  10
mdrp[min,rnd,grey]  26
srp0    27
mdrp[rp0,rnd,grey]  23
mirp[min,rnd,grey]  hstem 12
mirp[rp0,rnd,grey]  w_881 34
mirp[min,rnd,grey]  hstem 1
mirp[rp0,rnd,grey]  hnext_2  38
mirp[min,rnd,grey]  hstem 36
srp0    23
mirp[rp0,rnd,grey]  headdia_plus 18
mirp[min,rnd,grey]  headstem 42
mirp[rnd,grey]  headstem_plus_hole 48
IUP[x]
SVTCA[y-axis]
mdap[rnd]  1
mirp[rnd,grey]  vheight_lo 21
mirp[rnd,grey]  vheight 38
mirp[min,rnd,grey]  vstem 35
mirp[rp0,rnd,grey]  vheight_shoot 31
mirp[min,rnd,grey]  vstem_curve 5
srp0    21
mirp[min,rnd,grey] headstem 39
mirp[rp0,rnd,grey] headdia 15
mirp[min,rnd,grey]  headstem 45
srp1    5
srp2    1
sloop   10
ip  28 8 27 9 26 10 2 34 24 12
IUP[y]
""",

    #do_chada
    "uni0E0E": """
srp0    74
mirp[rp0,min,rnd,grey] front_khai 35
mirp[min,rnd,grey]  headstem 61
mirp[rnd,grey]  headstem_plus_hole 55
mirp[rp0,rnd,grey]  headdia_plus    29
mirp[rp0,min,rnd,grey]  hstem 40
mdrp[rp0,rnd,grey]  44
mdrp[min,rnd,grey]  25
mdrp[rp0,rnd,grey]  27
mdrp[min,rnd,grey]  43
srp0    40
mirp[rp0,rnd,grey]  w_836 51
mirp[min,rnd,grey]  hstem 18
shp[rp2]    1
srp0    40
mdrp[rp0,rnd,grey]  8
mirp[min,rnd,grey]  sarastem 71
srp1    71
srp2    18
sloop   6
ip  66 13 14 3 16 15
IUP[x]
SVTCA[y-axis]
mdap[rnd]   74
mirp[rnd,grey]  vheight_lo 32
mirp[rnd,grey]  vheight_lu 1
shp[rp2]    5
mirp[rp0,rnd,grey]  vheight_shoot 48
mirp[min,rnd,grey]  vstem_curve   22
srp0    32
mirp[min,rnd,grey]  headstem 52
mirp[rp0,rnd,grey]  headdia 38
mirp[min,rnd,grey]  headstem 58
srp0    5
mirp[min,rnd,grey]  headstem   64
mdrp[rp0,rnd,grey]  11
mirp[min,rnd,grey]  headstem   68
sloop   6
ip  14 15 13 16 66 3
srp0    1
mdrp[min,rnd,grey]  18
srp1    22
srp2    32
sloop   10
ip  45 25 44 26 43 27 19 51 41 29
IUP[y]
""",

    #to_patak
    "uni0E0F": """
srp0    78
mirp[rp0,min,rnd,grey]  front_khai 41
mirp[min,rnd,grey]  headstem 67
mirp[rnd,grey]  headstem_plus_hole 61
mirp[rp0,rnd,grey]  headdia_plus 35
mirp[rp0,min,rnd,grey]  hstem 46
mdrp[rp0,rnd,grey]  50
mdrp[min,rnd,grey]  31
mdrp[rp0,rnd,grey]  33
mdrp[min,rnd,grey]  49
srp0    46
mirp[rp0,rnd,grey]  w_836 57
mirp[min,rnd,grey]  hstem 24
shp[rp2]    1
srp0    46
mdrp[rp0,rnd,grey]  11
mirp[min,rnd,grey]  headstem 76
srp1    76
srp2    24
sloop   12
ip  72 16 17 6 19 18 4 21 3 22 2 23
IUP[x]
SVTCA[y-axis]
mdap[rnd]   78
mirp[rnd,grey]  vheight_lo 38
mirp[rnd,grey]  vheight_lu 8
mirp[rp0,rnd,grey]  vheight_shoot 54
mirp[min,rnd,grey]  vstem_curve   28
srp0    38
mirp[min,rnd,grey]  headstem 58
mirp[rp0,rnd,grey]  headdia 44
mirp[min,rnd,grey]  headstem 64
srp0   8
alignrp 4
alignrp 1 
mirp[min,rnd,grey]  headstem   70
mdrp[rp0,rnd,grey]  14
mirp[min,rnd,grey]  headstem   74
sloop   9
ip  17 16 19 22 72 6 21 24 2
srp1    28
srp2    38
sloop   10
ip  51 31 50 32 49 33 25 57 47 35
IUP[y]
""",

    #tho_than
    "uni0E10": """
srp0    117
mirp[rp0,min,rnd,grey]  front_kai 19
mdrp[min,rnd,grey]  41
mirp[rp0,rnd,grey]  hwidth_13   44
mirp[min,rnd,grey]  hstem   16
mdrp[min,rnd,grey]  31
srp0    16
mdrp[rp0,min,rnd,grey]  12
mdrp[rnd,grey]  13
mdrp[min,rnd,grey]  2
mdrp[min,rnd,grey]  50
mdrp[rp0,rnd,grey]  7
mirp[min,rnd,grey]  headstem    56
srp0    13
mdrp[rp0,min,rnd,grey]  1
mirp[min,rnd,grey]  hstem   0
mdrp[rp0,rnd,grey]  96
mdrp[min,rnd,grey]  85
mdrp[min,rnd,grey]  100
mdrp[rp0,rnd,grey]  91
mdrp[min,rnd,grey]  106
srp0    96
mdrp[rp0,min,rnd,grey]  70
mdrp[min,rnd,grey]  115
srp1    115
srp2    85
sloop   13
ip  111 75 77 65 80 78 63 82 62 83 61 84 60
IUP[x]
SVTCA[y-axis]                       ;Set freedom and projection Vectors To Coordinate Axis
mdap[rnd]   1
mdrp[min,rnd,grey]  13
mirp[rp0,rnd,grey]  vheight_shoot   23
mirp[min,rnd,grey]  vstem_curve 38
mdrp[rp0,rnd,grey]  30
mirp[min,rnd,grey]  vstem_curve 31
mdrp[rp0,rnd,grey]  33
mirp[min,rnd,grey]  vstem_curve 28
srp1    23
srp2    33
sloop   4
ip  25 26 36 35
srp0    38
mdrp[rp0,rnd,grey]  10
mirp[min,rnd,grey]  headstem    53
mirp[rp0,rnd,grey]  headdia 4
mirp[min,rnd,grey]  headstem 47
srp1    38
srp2    10
sloop   7
ip  20 41 19 42 18 16 44
srp0    1
mdrp[rp0,min,rnd,grey]  94
mdrp[min,rnd,grey]  103
mdrp[rp0,rnd,grey]  88
mdrp[min,rnd,grey]  97
mdrp[rp0,rnd,grey]  59
alignrp 62
alignrp 67
srp0    67
mdrp[min,rnd,grey]  109
mdrp[rp0,rnd,grey]  73
mdrp[min,rnd,grey]  113
srp1    73
srp2    67
sloop   10
ip  77 75 78 111 80 83 65 82 85 61
IUP[y]
""",

    #tho_than_descless
    "uni0E10.descless": """
srp0    59
mirp[rp0,min,rnd,grey]  front_kai 19
mdrp[min,rnd,grey]  41
mirp[rp0,rnd,grey]  hwidth_13   44
mirp[min,rnd,grey]  hstem   16
mdrp[min,rnd,grey]  31
srp0    16
mdrp[rp0,min,rnd,grey]  12
mdrp[rnd,grey]  13
mdrp[min,rnd,grey]  2
mdrp[min,rnd,grey]  50
mdrp[rp0,rnd,grey]  7
mirp[min,rnd,grey]  headstem    56
srp0    13
mdrp[rp0,min,rnd,grey]  1
mirp[min,rnd,grey]  hstem   0
IUP[x]
SVTCA[y-axis]                       ;Set freedom and projection Vectors To Coordinate Axis
mdap[rnd]   1
mdrp[min,rnd,grey]  13
mirp[rp0,rnd,grey]  vheight_shoot   23
mirp[min,rnd,grey]  vstem_curve 38
mdrp[rp0,rnd,grey]  30
mirp[min,rnd,grey]  vstem_curve 31
mdrp[rp0,rnd,grey]  33
mirp[min,rnd,grey]  vstem_curve 28
srp1    23
srp2    33
sloop   4
ip  25 26 36 35
srp0    38
mdrp[rp0,rnd,grey]  10
mirp[min,rnd,grey]  headstem    53
mirp[rp0,rnd,grey]  headdia 4
mirp[min,rnd,grey]  headstem 47
srp1    38
srp2    10
sloop   7
ip  20 41 19 42 18 16 44
IUP[y]
""",

    #tho_nangmontho
    "uni0E11": """
srp0    66
mirp[rp0,min,rnd,grey]  front_khai 33
mdrp[min,rnd,grey]  22
mdrp[rp0,rnd,grey]  27
mirp[min,rnd,grey]  headstem 57
mirp[rnd,grey]  headstem_plus_hole 63
srp0    33
mdrp[rp0,rnd,grey]  40
mirp[min,rnd,grey]  vstem 16
srp1    22
sloop   6
ip  36 20 37 19 38 18
mdrp[rp0,rnd,white] 48
mdrp[rp0,rnd,grey]  53
ip  6
mirp[min,rnd,grey]  hstem 1
mdrp[rnd,white] 67
mirp[rp0,rnd,grey]  w_905   10
mirp[min,rnd,grey]  hstem 45
shp[rp2]    9
IUP[x]
SVTCA[y-axis]                       ;Set freedom and projection Vectors To Coordinate Axis
mdap[rnd]   10
alignrp 1
mirp[min,rnd,grey]  vstem_curve 46
mirp[rp0,rnd,grey]  vheight_shoot   51
alignrp 36
alignrp 38
mirp[min,rnd,grey]  vstem_curve 4
srp0    36
mirp[min,rnd,grey]  sarastem 20
shp[rp2]    18
mdrp[rp0,min,rnd,grey]  37
mirp[min,rnd,grey]  headstem 19
mdrp[rp0,rnd,white]  24
mirp[min,rnd,grey]  headstem    60
mirp[rp0,rnd,grey]  headdia 30
mirp[min,rnd,grey]  headstem 54
IUP[y]
""",

    #to_putao
    "uni0E12": """
SRP0                    82         ;Set Reference Point 0
MIRP[rp0,min,rnd,grey]  front_dek 44    ;Move Indirect Relative Point
mirp[rp0,min,rnd,grey]  hstem 22
mdrp[rp0,rnd,grey]  25
mdrp[rp0,min,rnd,grey]  41
mirp[min,rnd,grey]  hstem 40
srp0    25
mdrp[rp0,rnd,white] 30
mirp[min,rnd,grey]  headstem 67
mirp[rp0,rnd,grey]  headdia 36
mirp[min,rnd,grey]  headstem 61
#mdrp[rp0,rnd,grey]  38
mdrp[min,rnd,grey]  27
mdrp[rp0,rnd,white]  11
mirp[min,rnd,grey]  headstem 79
mirp[rp0,rnd,grey]  headdia 5
mirp[min,rnd,grey]  headstem 73
mdrp[rp0,rnd,grey]  3
mdrp[rp0,rnd,grey]  52
mirp[min,rnd,grey]  hstem 14
mirp[rp0,rnd,grey]  hnext_2 57
MIRP[min,rnd,grey]  hstem  55      ;Move Indirect Relative Point
shp[rp2]            1
MDRP[min,rnd,grey]  83         ;Move Direct Relative Point
srp1    22
srp2    15
sloop   7
ip  47 20 48 19 18 49 17
IUP[x]                              ;Interpolate Untouched Points through the outline
SVTCA[y-axis]                       ;Set freedom and projection Vectors To Coordinate Axis
MDAP[rnd]               1          ;Move Direct Absolute Point
ALIGNRP                 40         ;ALIGN to Reference Point
mirp[min,rnd,grey]      vstem_curve 55
shp[rp2]                25
mirp[rnd,grey]          vheight_lo  8
mirp[rnd,grey]          vheight 57
MIRP[rp0,rnd,grey]      vheight_shoot  49     ;Move Indirect Relative Point
alignrp 47
MIRP[min,rnd,grey]      vstem  17     ;Move Indirect Relative Point
shp[rp2]    20
mdrp[rp0,rnd,grey]  48
mirp[rp0,min,rnd,grey]  headstem 18
mdrp[rp0,rnd,white]  33
mirp[min,rnd,grey]  headstem 64
mirp[rp0,rnd,grey]  headdia 27
mirp[min,rnd,grey]  headstem 58
srp0    8
mirp[min,rnd,grey]  headstem 70
mirp[rp0,rnd,grey]  headdia 14
mirp[min,rnd,grey]  headstem 76
sloop 2
ip  53 3
srp1    18
srp2    25
sloop   4
ip  42 22 15 52
IUP[y]                              ;Interpolate Untouched Points
""",

    #no_nane
    "uni0E13": """
srp0    77
mirp[rp0,min,rnd,grey]  front_kai 27
mdrp[min,rnd,grey]  8
mdrp[rp0,rnd,grey]  10
mdrp[min,rnd,grey]  26
srp0    27
mdrp[rp0,rnd,grey]  23
mirp[min,rnd,grey]  hstem 12
mirp[rp0,rnd,grey]  w_881  34
alignrp 0
mirp[min,rnd,grey]  hstem 1
mirp[rp0,rnd,grey]  hnext_1 39
mirp[min,rnd,grey]  hstem 37
srp0    23
mirp[rp0,rnd,grey]  headdia_plus    18
mirp[min,rnd,grey]  headstem 56
mirp[rnd,grey]  headstem_plus_hole 62
srp0    0
mdrp[rp0,rnd,grey] 49
mirp[min,rnd,grey]  headstem 74
mirp[rp0,rnd,grey]  headdia 43
mirp[min,rnd,grey]  headstem 68
mdrp[min,rnd,grey]  78
IUP[x]
SVTCA[y-axis]
mdap[rnd]  1
mirp[min,rnd,grey]  vstem_curve 35
mirp[rnd,grey]  vheight_lo 21
shp[rp2]    46
mirp[rnd,grey]  vheight 39
mirp[rp0,rnd,grey]  vheight_shoot 31
mirp[min,rnd,grey]  vstem_curve 5
srp0    21
mirp[min,rnd,grey] headstem 53
mirp[rp0,rnd,grey] headdia 15
mirp[min,rnd,grey] headstem 59
srp0    46
mirp[min,rnd,grey] headstem 65
mdrp[rp0,rnd,grey]  40
mdrp[min,rnd,grey]  71
mdrp[rp0,rnd,grey]  37
mdrp[min,rnd,grey]  51
srp1    5
srp2    15
sloop   10
ip  28 8 27 9 26 10 2 34 24 12
IUP[y]
""",

    #do_dek
    "uni0E14": """
SRP0    49         ;Set Reference Point 0
MIRP[rp0,min,rnd,grey]   front_kai 30    ;Move Indirect Relative Point
mirp[min,rnd,grey]  hstem 8
mirp[rp0,rnd,grey]  w_309 16
mirp[min,rnd,grey]  headstem 46
mirp[rp0,rnd,grey]  headdia 22
mdrp[min,rnd,grey]  13
mirp[min,rnd,grey]  headstem 40
srp0    30
mirp[rp0,rnd,grey]  w_1001 36
mirp[min,rnd,grey]  hstem 1
mdrp[rnd,white] 50
srp0    8
mdrp[rp0,rnd,grey]  11
mdrp[rp0,rnd,grey]      27
MIRP[min,rnd,grey]  hstem  26      ;Move Indirect Relative Point
IUP[x]                              ;Interpolate Untouched Points through the outline
SVTCA[y-axis]                       ;Set freedom and projection Vectors To Coordinate Axis
MDAP[rnd]                1          ;Move Direct Absolute Point
ALIGNRP                  26         ;ALIGN to Reference Point
MIRP[rp0,rnd,grey]       vheight_shoot  33     ;Move Indirect Relative Point
MIRP[min,rnd,grey]       vstem_curve  5      ;Move Indirect Relative Point
mdrp[rp0,rnd,grey]      13
mirp[min,rnd,grey]      headstem 37
mirp[rp0,rnd,grey]      headdia 19
mirp[min,rnd,grey]      headstem 43
srp0                    26
mirp[min,rnd,grey]      vstem 11
srp1                    5
srp2                    11
sloop                   4
ip                      30 8 2 36
IUP[y]                              ;Interpolate Untouched Points 
""",

    #to_tao
    "uni0E15": """
SRP0                     52         ;Set Reference Point 0
MIRP[rp0,min,rnd,grey]   front_kai 31    ;Move Indirect Relative Point
mirp[min,rnd,grey]  hstem 9
mirp[rp0,rnd,grey]  w_1001 39
sloop 7
ip  34 7 35 6 5 36 4
mdrp[rnd,white] 53
mirp[min,rnd,grey]  hstem 1
srp0    31
mirp[rp0,rnd,grey]  w_309 17
mirp[min,rnd,grey]  headstem 49
mirp[rp0,rnd,grey]  headdia 23
mirp[min,rnd,grey]  headstem 43
mdrp[min,rnd,grey]  14
srp0    9
mdrp[rp0,rnd,grey]  12
mdrp[rp0,rnd,grey]  28
mirp[min,rnd,grey]  hstem 27
IUP[x]                              ;Interpolate Untouched Points through the outline
SVTCA[y-axis]                       ;Set freedom and projection Vectors To Coordinate Axis
MDAP[rnd]               1          ;Move Direct Absolute Point
ALIGNRP                 27         ;ALIGN to Reference Point
MIRP[rp0,rnd,grey]      vheight_shoot  36     ;Move Indirect Relative Point
alignrp 34
MIRP[min,rnd,grey]      vstem_curve  4      ;Move Indirect Relative Point
shp[rp2]    7
mirp[rp0,min,rnd,grey]  vstem 35
mirp[rp0,min,rnd,grey]  sarastem 5
mdrp[rp0,min,rnd,grey]  20
mirp[min,rnd,grey]  headstem 46
mirp[rp0,rnd,grey]  headdia 14
mirp[min,rnd,grey]  headstem 40
srp0    27
mirp[min,rnd,grey]  vstem_curve 12
srp1    5
srp2    12
sloop   4
ip  31 9 2 39
IUP[y]                              ;Interpolate Untouched Points 
""",

    #to_tung
    "uni0E16": """
srp0    47
mirp[rp0,min,rnd,grey] front_kai 27
mdrp[min,rnd,grey]  8
mdrp[rp0,rnd,grey]  10
mdrp[min,rnd,grey]  26
srp0    27
mdrp[rp0,rnd,grey]  23
mirp[min,rnd,grey]  hstem 12
mirp[rp0,rnd,grey]  w_881 34
mirp[min,rnd,grey]  hstem 1
srp0   23
mirp[rp0,rnd,grey]  headdia_plus 18
mirp[min,rnd,grey]  headstem 38 
mirp[rnd,grey]  headstem_plus_hole 44
IUP[x]
SVTCA[y-axis]
mdap[rnd]  1
mirp[rnd,grey]  vheight_lo 21
mirp[rp0,rnd,grey]  vheight_shoot 31
mirp[min,rnd,grey]  vstem_curve 5
srp0    21
mirp[min,rnd,grey]  headstem    35
mirp[rp0,rnd,grey]  headdia 15
mirp[min,rnd,grey]  headstem    41
srp1    5
srp2    1
sloop   10
ip  28 8 27 9 26 10 2 34 24 12
IUP[y]
""",

    #to_tahan
    "uni0E17": """
srp0    40
mirp[rp0,min,rnd,grey] front_khai 15
mirp[min,rnd,grey]  headstem 37
mirp[rnd,grey]  headstem_plus_hole 31
mirp[rp0,rnd,grey]  headdia_plus 20
mirp[rp0,min,rnd,grey]  hstem 9
mirp[rp0,rnd,grey]  w_881   27
mdrp[rnd,white] 41
mirp[min,rnd,grey]  hstem 1
srp2   20
sloop   5
ip  8 23 6 4 25
IUP[x]
SVTCA[y-axis]
mdap[rnd]  1
alignrp 8
mirp[rp0,rnd,grey]  vheight_shoot 25
alignrp 18
mirp[min,rnd,grey]  vstem_curve 4
srp0    18
mirp[min,rnd,grey]  headstem 34
mirp[rp0,rnd,grey]  headdia 12
mirp[min,rnd,grey]  headstem 28
srp0    8
mdrp[min,rnd,grey]  21
srp1    25
srp2    21
sloop   5
ip  20 23 6 4 27
IUP[y]
""",

    #to_thong
    "uni0E18": """
srp0    39
mirp[rp0,min,rnd,grey] front_kai 11
mdrp[min,rnd,grey]  33
mdrp[rp0,rnd,grey]  1
mirp[min,rnd,grey]  hstem 3
mirp[rp0,rnd,grey]  w_758 36
mirp[min,rnd,grey]  hstem 7
mdrp[rp0,rnd,grey]  23
mdrp[rnd,white] 40
IUP[x]
SVTCA[y-axis]
mdap[rnd]  1
mirp[min,rnd,grey]  vstem 4
mirp[rp0,rnd,grey]  vheight_shoot 15
mirp[min,rnd,grey]  vstem_curve 30
mdrp[rp0,rnd,grey]  22
mirp[min,rnd,grey]  vstem_curve 23
mdrp[rp0,rnd,grey]  25
mirp[min,rnd,grey]  vstem_curve 20
srp2    15
sloop   4
ip  28 27 17 18
srp1    30
srp2    4
sloop   7
ip  12 33 11 34 3 8 36
srp0 34
mirp[rp0,min,rnd,grey]  vstem 10
IUP[y]
""",

    #no_nu
    "uni0E19": """
srp0    55
mirp[rp0,min,rnd,grey] front_khai 7
mirp[min,rnd,grey]  headstem 40
mirp[rnd,grey]  headstem_plus_hole 34
mirp[rp0,rnd,grey]  headdia_plus 12
alignrp 0
mirp[rp0,min,rnd,grey]  hstem 1
mirp[rp0,rnd,grey]  w_720 17
mirp[min,rnd,grey]  hstem 15
mdrp[rp0,rnd,grey]  21
mdrp[rnd,white]  56
mirp[min,rnd,grey]  headstem 46
mirp[rp0,rnd,grey]  headdia 27
mdrp[rnd,grey]  29
mirp[min,rnd,grey]  headstem 52
IUP[x]
SVTCA[y-axis]
mdap[rnd]  1
mirp[rnd,grey]  vheight_lo 24
mirp[rnd,grey]  vheight 17
mdrp[min,rnd,grey]  13
mirp[rp0,min,rnd,grey]  vheight_shoot 10
mirp[min,rnd,grey]  headstem 37
mirp[rp0,rnd,grey]  headdia 4
mirp[min,rnd,grey]  headstem 31
srp0    24
mirp[min,rnd,grey]  headstem 43
mdrp[rp0,rnd,grey]  18
mdrp[min,rnd,grey]  49
mdrp[rp0,rnd,grey]  15
mdrp[min,rnd,grey]  29
IUP[y]
""",

    #bo_baimai
    "uni0E1A": """
srp0    29
mirp[rp0,min,rnd,grey] front_khai 7
mirp[min,rnd,grey]  headstem 26
mirp[rnd,grey]  headstem_plus_hole 20
mirp[rp0,rnd,grey]  headdia_plus 12
mirp[rp0,min,rnd,grey]  hstem 1
mirp[rp0,rnd,grey]  w_821 16
mdrp[rnd,white]  30
mirp[min,rnd,grey]  hstem 14
IUP[x]
SVTCA[y-axis]
mdap[rnd]  1
mirp[rnd,grey]  vheight 16
mirp[min,rnd,grey]  vstem 13
mirp[rp0,rnd,grey]  vheight_shoot 10
mirp[min,rnd,grey]  headstem 23
mirp[rp0,rnd,grey]  headdia 4
mirp[min,rnd,grey]  headstem 17
IUP[y]
""",

    #po_pla
    "uni0E1B": """
srp0    29
mirp[rp0,min,rnd,grey] front_khai 7
mirp[min,rnd,grey]  headstem 26
mirp[rnd,grey]  headstem_plus_hole 20
mirp[rp0,rnd,grey]  headdia_plus 12
mirp[rp0,min,rnd,grey]  hstem 1
mirp[rp0,rnd,grey]  w_821 16
mdrp[rnd,white]  30
mirp[min,rnd,grey]  hstem 14
IUP[x]
SVTCA[y-axis]
mdap[rnd]  1
mirp[rnd,grey]  vheight_po 16
mirp[min,rnd,grey]  vstem 13
mirp[rp0,rnd,grey]  vheight_shoot 10
mirp[min,rnd,grey]  headstem 23
mirp[rp0,rnd,grey]  headdia 4
mirp[min,rnd,grey]  headstem 17
IUP[y]
""",

    #po_pung
    "uni0E1C": """
srp0    34
mirp[rp0,min,rnd,grey]  front_pung 5
mirp[min,rnd,grey]  hstem 15
shp[rp2]    3
mirp[rp0,rnd,grey]  hwidth_7 21
mdrp[rnd,white] 35
mirp[min,rnd,grey]  hstem   19
shp[rp2]    1
mdrp[min,rnd,grey]  35
srp0    5
mdrp[rp0,rnd,grey]  10
mirp[min,rnd,grey]  headstem 25
mirp[rnd,grey]  headstem_plus_hole 31
srp1    15
srp2    19
sloop 3
ip  17 2 18
IUP[x]
SVTCA[y-axis]
mdap[rnd]   1
alignrp     3
mdrp[min,rnd,grey]  19
shp[rp2]    16
mirp[rnd,grey]  vheight 21
mirp[rp0,rnd,grey]  vheight_shoot 7
mirp[min,rnd,grey]  headstem 28
mirp[rp0,rnd,grey]  headdia 13
mirp[min,rnd,grey]  headstem 22
mdrp[rp0,rnd,white] 17
mirp[min,rnd,grey]  vstem 2
IUP[y]
""",

    #fo_fa
    "uni0E1D": """
srp0    34
mirp[rp0,min,rnd,grey]  front_pung 5
mirp[min,rnd,grey]  hstem 15
shp[rp2]    3
mirp[rp0,rnd,grey]  hwidth_7 21
mdrp[rnd,white] 35
mirp[min,rnd,grey]  hstem   19
shp[rp2]    1
mdrp[min,rnd,grey]  35
srp0    5
mdrp[rp0,rnd,grey]  10
mirp[min,rnd,grey]  headstem 25
mirp[rnd,grey]  headstem_plus_hole 31
srp1    15
srp2    19
sloop 3
ip  17 2 18
IUP[x]
SVTCA[y-axis]
mdap[rnd]   1
alignrp     3
mdrp[min,rnd,grey]  19
shp[rp2]    16
mirp[rnd,grey]  vheight_po 21
mirp[rp0,rnd,grey]  vheight_shoot 7
mirp[min,rnd,grey]  headstem 28
mirp[rp0,rnd,grey]  headdia 13
mirp[min,rnd,grey]  headstem 22
mdrp[rp0,rnd,white] 17
mirp[min,rnd,grey]  vstem 2
IUP[y]
""",

    #po_pan
    "uni0E1E": """
srp0    34
mirp[rp0,min,rnd,grey]  front_khai 10
mirp[min,rnd,grey]  headstem 31
mirp[rnd,grey]  headstem_plus_hole 25
mirp[rp0,rnd,grey]  headdia_plus 15
mirp[rp0,min,rnd,grey]  hstem 4
mirp[rp0,rnd,grey]  w_938 21
mirp[min,rnd,grey]  hstem   19
mdrp[rnd,white] 35
srp1    15
srp2    19
sloop   5
ip      3 1 17 2 18 
IUP[x]
SVTCA[y-axis]
mdap[rnd]   1
alignrp     3
mdrp[min,rnd,grey]  19
shp[rp2]    16
mirp[min,rnd,grey]  vheight 21
mirp[rp0,rnd,grey]  vheight_shoot 13
mirp[min,rnd,grey]  headstem 28
mirp[rp0,rnd,grey]  headdia 7
ip  17
ip  2
mirp[min,rnd,grey]  headstem 22
IUP[y]
""",

    #fo_fun
    "uni0E1F": """
srp0    34
mirp[rp0,min,rnd,grey]  front_khai 10
mirp[min,rnd,grey]  headstem 31
mirp[rnd,grey]  headstem_plus_hole 25
mirp[rp0,rnd,grey]  headdia_plus 15
alignrp 3
mirp[rp0,min,rnd,grey]  hstem 4
mirp[rp0,rnd,grey]  w_938 21
mirp[min,rnd,grey]  hstem   19
shp[rp2]    1
mdrp[rnd,white] 35
srp1    15
srp2    19
sloop   3
ip      17 2 18 
IUP[x]
SVTCA[y-axis]
mdap[rnd]   1
alignrp     3
mdrp[min,rnd,grey]  19
shp[rp2]    16
mirp[min,rnd,grey]  vheight_po 21
mirp[rp0,rnd,grey]  vheight_shoot 13
mirp[min,rnd,grey]  headstem 28
mirp[rp0,rnd,grey]  headdia 7
mirp[min,rnd,grey]  headstem 22
srp1    13
srp2    19
sloop   2
ip  17 2
IUP[y]
""",

    #po_sampao
    "uni0E20": """
srp0    47
mirp[rp0,min,rnd,grey]  front_khai 18
mirp[min,rnd,grey]  headstem 44
mirp[rnd,grey]  headstem_plus_hole 38
mirp[rp0,rnd,grey]  headdia_plus 12
mirp[rp0,min,rnd,grey]  hstem 23
mdrp[rp0,rnd,grey]  27
mdrp[min,rnd,grey]  8
mdrp[rp0,rnd,grey]  10
mdrp[min,rnd,grey]  26
srp0    23
mirp[rp0,rnd,grey]  w_836   34
mirp[min,rnd,grey]  hstem   1
IUP[x]
SVTCA[y-axis]
mdap[rnd]  1
mirp[rnd,grey]  vheight_lo 15
mirp[rp0,rnd,grey]  vheight_shoot 31
mirp[min,rnd,grey]  vstem_curve   5
srp0    15
mirp[min,rnd,grey]  headstem 35
mirp[rp0,rnd,grey]  headdia 21
mirp[min,rnd,grey]  headstem 41
srp1    5
srp2    1
sloop   10
ip  28 8 27 9 26 10 2 34 24 12
IUP[y]
""",

    #mo_ma
    "uni0E21": """
srp0    55
mirp[rp0,min,rnd,grey]  front_khai 9
mirp[min,rnd,grey]  headstem 52
mirp[rp0,rnd,grey]  headstem_plus_hole 46
alignrp 14
mirp[min,rnd,grey]  hstem 25
shp[rp2]    3
mirp[rp0,rnd,grey]  w_758 30
mdrp[rnd,white] 56
mirp[min,rnd,grey]  hstem 28
shp[rp2]    1
srp0    25
mirp[rp0,rnd,grey]  headdia_plus    20
mirp[min,rnd,grey]  headstem 40
mirp[rnd,grey]  headstem_plus_hole 34
IUP[x]
SVTCA[y-axis]
mdap[rnd]   1
mirp[rnd,grey]  vheight_lo 6
mirp[rnd,grey]  vheight 30
mirp[min,rnd,grey]  vstem 28
mirp[rp0,rnd,grey]  vheight_shoot 23
mirp[min,rnd,grey]  headstem 37
mirp[rp0,rnd,grey]  headdia 17
mirp[min,rnd,grey]  headstem 31
srp0    6
mdrp[min,rnd,grey]  43
mdrp[rp0,rnd,grey]  12
mdrp[min,rnd,grey]  49
mdrp[rp0,rnd,grey]  26
mdrp[min,rnd,grey]  3
IUP[y]
""",

    #yo_yak
    "uni0E22": """
srp0    46
mirp[rp0,min,rnd,grey]  front_dek 7
mdrp[rnd,grey]  33
mdrp[min,rnd,grey]  4
mirp[rp0,min,rnd,grey]  vstem   21
mdrp[rp0,rnd,white]  19
mdrp[rp0,rnd,grey]  13
mirp[min,rnd,grey]  headstem 37
mirp[rnd,grey]  headstem_plus_hole 43
srp0    33
mirp[min,rnd,grey]  hstem 31
mirp[rp0,rnd,grey]  w_881 1
ip  26
mirp[min,rnd,grey]  hstem 29
IUP[x]
SVTCA[y-axis]
mdap[rnd] 1
mirp[rnd,grey]      vheight 33
mirp[min,rnd,grey]  vstem 30
mirp[rp0,rnd,grey]  vheight_shoot 10
mdrp[rnd,grey]  19
mirp[min,rnd,grey]  headstem 40
mirp[rp0,rnd,grey]  headdia 16
mirp[min,rnd,grey]  headstem 34
srp1    16
srp2    30
sloop   9
ip  6 5 22 25 4 3 26 2 29
IUP[y]
""",

    #ro_ruar
    "uni0E23": """
srp0    52
mdrp[rp0,min,rnd,grey]  12
mirp[min,rnd,grey]  vstem   34
mirp[rp0,rnd,grey]  w_758 37
mirp[min,rnd,grey]  hstem 8
mdrp[rp0,rnd,grey]  24
mdrp[rnd,white] 53
srp0    37
mirp[rp0,rnd,grey]  headdia_plus 3
mirp[min,rnd,grey]  headstem 49
mirp[rnd,grey]  headstem_plus_hole 43
srp1    34
srp2    24
sloop   6
ip  18 19 29 28 35 11
IUP[x]
SVTCA[y-axis]
mdap[rnd]  0
mirp[rp0,rnd,grey]  vheight_shoot 16
mirp[min,rnd,grey]  vstem_curve 31
mdrp[rp0,rnd,grey]  23
mirp[min,rnd,grey]  vstem_curve 24
mdrp[rp0,rnd,grey]  26
mirp[min,rnd,grey]  vstem_curve 21
srp0    0
mirp[min,rnd,grey]  headstem 40
mirp[rp0,rnd,grey]  headdia 6
mirp[min,rnd,grey]  headstem 46
srp1 31
srp2 6
sloop 6
ip 13 34 12 35 9 37
srp0 35
mdrp[rp0,rnd,grey]  35
mirp[min,rnd,grey]  sarastem 11
IUP[y]
""",

    #lo_lu
    "uni0E24": """
srp0    47
mirp[rp0,min,rnd,grey] front_kai 27
mdrp[min,rnd,grey]  8
mdrp[rp0,rnd,grey]  10
mdrp[min,rnd,grey]  26
srp0    27
mdrp[rp0,rnd,grey]  23
mirp[min,rnd,grey]  hstem 12
mirp[rp0,rnd,grey]  w_881 34
mirp[min,rnd,grey]  hstem 1
srp0   23
mirp[rp0,rnd,grey]  headdia_plus 18
mirp[min,rnd,grey]  headstem 38 
mirp[rnd,grey]  headstem_plus_hole 44
IUP[x]
SVTCA[y-axis]
mdap[rnd]  47
mirp[rnd,grey]  vheight_lu 0
mirp[rnd,grey]  vheight_lo 21
mirp[rp0,rnd,grey]  vheight_shoot 31
mirp[min,rnd,grey]  vstem 5
srp0    21
mirp[min,rnd,grey]  headstem    35
mirp[rp0,rnd,grey]  headdia 15
mirp[min,rnd,grey]  headstem    41
srp1    5
srp2    1
sloop   10
ip  28 8 27 9 26 10 2 34 24 12
IUP[y]
""",

    #lo_ling
    "uni0E25": """
srp0    51
mirp[rp0,min,rnd,grey] front_dek 17
alignrp 31
mirp[min,rnd,grey]  hstem 6
mirp[rp0,rnd,grey]  w_905 38
mirp[min,rnd,grey]  hstem 24
shp[rp2]    1
srp0    17
mirp[rp0,rnd,grey]  headdia_plus 12
mirp[min,rnd,grey]  headstem 42
mirp[rnd,grey]  headstem_plus_hole 48
IUP[x]
SVTCA[y-axis]
mdap[rnd]  1
mirp[rnd,grey]  vheight_lo 15
mdrp[min,rnd,grey]  24
mirp[rp0,rnd,grey]  vheight_shoot 35
mirp[min,rnd,grey]  vstem_curve 28
mdrp[rp0,rnd,grey]  21
mirp[min,rnd,grey]  vstem_curve   4
srp0    15
mirp[min,rnd,grey]  headstem 39
mirp[rp0,rnd,grey]  headdia 9
mirp[min,rnd,grey]  headstem 45
srp1    28
srp2    9
sloop   4
ip  18 6 25 38
IUP[y]
""",

    #ro_ru
    "uni0E26": """
srp0    47
mirp[rp0,min,rnd,grey]  front_khai 18
mirp[min,rnd,grey]  headstem 44
mirp[rnd,grey]  headstem_plus_hole 38
mirp[rp0,rnd,grey]  headdia_plus 12
mirp[rp0,min,rnd,grey]  hstem 23
mdrp[rp0,rnd,grey]  27
mdrp[min,rnd,grey]  8
mdrp[rp0,rnd,grey]  10
mdrp[min,rnd,grey]  26
srp0    23
mirp[rp0,rnd,grey]  w_836   34
mirp[min,rnd,grey]  hstem   1
IUP[x]
SVTCA[y-axis]
mdap[rnd]  47
mirp[rnd,grey]  vheight_lu 1
mirp[rnd,grey]  vheight_lo 15
mirp[rp0,rnd,grey]  vheight_shoot 31
mirp[min,rnd,grey]  vstem_curve   5
srp0    15
mirp[min,rnd,grey]  headstem 35
mirp[rp0,rnd,grey]  headdia 21
mirp[min,rnd,grey]  headstem 41
srp1    5
srp2    1
sloop   10
ip  28 8 27 9 26 10 2 34 24 12
IUP[y]
""",

    #wo_wan
    "uni0E27": """
srp0    37
mirp[rp0,min,rnd,grey]  front_khai 15
mirp[rp0,min,rnd,grey]  w_819 23
mdrp[rnd,white] 38
mirp[min,rnd,grey]  hstem 8
mirp[rp0,rnd,grey]  headdia_plus 3
mirp[min,rnd,grey]  headstem 34
mirp[rnd,grey]  headstem_plus_hole 28
IUP[x]
SVTCA[y-axis]
srp0    37
mirp[rnd,grey]  vheight_lo 0
mirp[rp0,rnd,grey]  vheight_shoot 19
mirp[min,rnd,grey]  vstem_curve   12
srp0    0
mirp[min,rnd,grey]  headstem 25
mirp[rp0,rnd,grey]  headdia 6
mirp[min,rnd,grey]  headstem 31
srp1    12
srp2    6
sloop   2
ip  9 22
IUP[y]
""",

    #so_sala
    "uni0E28": """
SRP0                    64         ;Set Reference Point 0
MIRP[rp0,min,rnd,grey]  front_kai 39    ;Move Indirect Relative Point
mirp[min,rnd,grey]  hstem 14
mirp[rp0,rnd,grey]  w_1001  51
mirp[min,rnd,grey]  hstem 1
sloop 6
ip 7 6 9 4 44 49
mdrp[rp0,rnd,grey]  47
mdrp[min,rnd,grey]  46
mdrp[rnd,white] 65
srp0    39
mirp[rp0,rnd,grey]  w_690 26
mirp[min,rnd,grey]  headstem 55
ip 7
ip 6
mirp[rnd,grey]  headstem_plus_hole 61
srp0    14
mdrp[rp0,rnd,grey]  17
mdrp[rp0,rnd,grey]  36
mirp[min,rnd,grey]  hstem 35
srp0    17
mdrp[min,rnd,grey]  33
mdrp[rp0,rnd,white] 20
mdrp[min,rnd,grey]  31
IUP[x]                              ;Interpolate Untouched Points through the outline
SVTCA[y-axis]                       ;Set freedom and projection Vectors To Coordinate Axis
MDAP[rnd]                35         ;Move Direct Absolute Point
ALIGNRP                  1         ;ALIGN to Reference Point
mdrp[min,rnd,grey]  17
MIRP[rp0,rnd,grey]       vheight_shoot  41     ;Move Indirect Relative Point
MIRP[min,rnd,grey]       vstem_curve  11     ;Move Indirect Relative Point
MDRP[rp0,rnd,grey]       23         ;Move Direct Relative Point
MIRP[min,rnd,grey]       headstem  58    ;Move Indirect Relative Point
MIRP[rp0,rnd,grey]       headdia  29    ;Move Indirect Relative Point
MIRP[min,rnd,grey]       headstem  52    ;Move Indirect Relative Point
srp1    42
srp2    23
sloop   8
ip  46 47 44 49 9 7 4 6
srp1    11
srp2    17
sloop 4
ip  39 14 2 51
IUP[y]                              ;Interpolate Untouched Points through the out
""",

    #so_lusi
    "uni0E29": """
srp0    64
mirp[rp0,min,rnd,grey] front_khai 7
mirp[min,rnd,grey]  headstem 49
mirp[rnd,grey]  headstem_plus_hole 43
mirp[rp0,rnd,grey]  headdia_plus 12
mirp[rp0,min,rnd,grey]  hstem   1
mirp[rp0,rnd,grey]  w_864 33
alignrp     39
mirp[min,rnd,grey]  hstem 31
shp[rp2]    14
mdrp[rp0,min,rnd,grey]  37
ip      36
mdrp[rnd,white] 65
srp0    31
mdrp[rp0,rnd,white] 26
mirp[min,rnd,grey]  headstem_tiny   55
mdrp[rnd,grey]  28
mirp[rp0,rnd,grey]  headdia_tiny    20
mirp[min,rnd,grey]  headstem_tiny   61
srp0    34
mdrp[min,rnd,grey]  36
mdrp[min,rnd,grey]  37
IUP[x]
SVTCA[y-axis]
mdap[rnd]  1
mirp[rnd,grey]      vheight 33
mirp[min,rnd,grey]  vstem   13
mirp[rp0,rnd,grey]  vheight_shoot 10
mirp[min,rnd,grey]  headstem 46
mirp[rp0,rnd,grey]  headdia 4
mirp[min,rnd,grey]  headstem 40
srp0    14
mdrp[rp0,min,rnd,white] 17
mirp[min,rnd,grey]  vstem_tiny 28
mdrp[rp0,rnd,grey]  23
mirp[min,rnd,grey]  headstem_tiny   58
mdrp[min,rnd,grey]  52
srp1    23
srp2    17
sloop   6
ip  36 34 37 31 39 15
IUP[y]
""",

    #so_sua
    "uni0E2A": """
srp0    63
mirp[rp0,min,rnd,grey]  front_dek 17
alignrp     37
mirp[min,rnd,grey]  hstem 6
mirp[rp0,rnd,grey]  w_905 50
mirp[min,rnd,grey]  hstem 24
shp[rp2]    1
mdrp[rp0,rnd,grey]  46
mdrp[rnd,white]     64
srp0    17
mirp[rp0,rnd,grey]  headdia_plus 12
mirp[min,rnd,grey]  headstem 54
mirp[rnd,grey]  headstem_plus_hole 60
srp1    25
srp2    46
sloop   7
ip  30 29 32 27 43 48 45
IUP[x]
SVTCA[y-axis]
mdap[rnd]  1
mirp[rnd,grey]  vheight_lo 15
mirp[rp0,rnd,grey]  vheight_shoot 41
mirp[min,rnd,grey]  vstem_curve 34
mdrp[rp0,rnd,grey]  21
mirp[min,rnd,grey]  vstem   4
srp0    15
mirp[min,rnd,grey]  headstem 51
mirp[rp0,rnd,grey]  headdia 9
mirp[min,rnd,grey]  headstem 57
srp1    41
srp2    21
sloop   8
ip  45 46 43 48 32 30 27 29
srp1    34
srp2    9
sloop   4
ip  18 6 25 50
IUP[y]
""",

    #ho_hib
    "uni0E2B": """
SRP0                    64         ;Set Reference Point 0
mirp[rp0,min,rnd,grey]  front_khai 15
mirp[min,rnd,grey]  headstem 49
mirp[rnd,grey]      headstem_plus_hole 43
mirp[rp0,rnd,grey]  headdia_plus 20
alignrp     8
mirp[rp0,min,rnd,grey]  hstem 9
mirp[rp0,rnd,grey]  w_881 39
ip  23
ip  6
alignrp     34
mirp[min,rnd,grey]  hstem 1
mdrp[rnd,grey]  37
mirp[min,rnd,grey]  headstem 55
mirp[rp0,rnd,grey]  headdia 28
mirp[min,rnd,grey]  headstem 61
mdrp[rnd,grey]  25  
IUP[x]                              ;Interpolate Untouched Points through the outline
SVTCA[y-axis]                       ;Set freedom and projection Vectors To Coordinate Axis
MDAP[rnd]                8          ;Move Direct Absolute Point
ALIGNRP                  1          ;ALIGN to Reference Point
mdrp[min,rnd,grey]      21
MIRP[rp0,rnd,grey]      vheight_shoot  18     ;Move Indirect Relative Point
alignrp     31
MIRP[min,rnd,grey]       headstem  46     ;Move Indirect Relative Point
shp[rp2]    58
MIRP[rp0,rnd,grey]       headdia  12    ;Move Indirect Relative Point
MIRP[min,rnd,grey]       headstem  40    ;Move Indirect Relative Point
shp[rp2]    52
srp1                    31
srp2                    8
sloop                   7
ip  25 37 4 23 6 2 39
IUP[y]                              ;Interpolate Untouched Points 
""",

    #lo_jula
    "uni0E2C": """
srp0    61
mirp[rp0,min,rnd,grey]  front_khai 10
mirp[min,rnd,grey]  headstem 46
mirp[rnd,grey]  headstem_plus_hole 40
mirp[rp0,rnd,grey]  headdia_plus 15
alignrp     3
mirp[rp0,min,rnd,grey]  hstem 4
mirp[rp0,rnd,grey]  w_938 36
alignrp     30
sloop 3
ip 17 2 18
mirp[min,rnd,grey]  hstem 19
shp[rp2]    1
mdrp[rp0,rnd,grey]  34
mdrp[rnd,white]     62
srp0    36
mirp[min,rnd,grey]  headstem 52
mirp[rp0,rnd,grey]  headdia 24
mirp[min,rnd,grey]  headstem 58
IUP[x]
SVTCA[y-axis]
srp0    1
alignrp    3
mdrp[min,rnd,grey]  19
shp[rp2]   16
mdrp[rnd,grey]  27
mirp[rp0,rnd,grey]  vheight_shoot 13
mirp[min,rnd,grey]  headstem 43
mirp[rp0,rnd,grey]  headdia 7
mirp[min,rnd,grey]  headstem 37
srp0    27
mirp[min,rnd,grey]  headstem 55
mirp[rp0,rnd,grey]  headdia 21
mirp[min,rnd,grey]  headstem 49
srp1    13
srp2    19
sloop   2
ip  17 2
srp1    27
srp2    21
sloop   4
ip  31 33 34 36
IUP[y]
""",

    #aw_ang
    "uni0E2D": """
srp0    41
mirp[rp0,min,rnd,grey]  front_dek 1
alignrp 21
mirp[min,rnd,grey]  hstem 12
mirp[rp0,rnd,grey]  w_836 28
mdrp[rnd,white] 42
mirp[min,rnd,grey]  hstem 14
srp0    1
mirp[rp0,rnd,grey]  headdia_plus 7
mirp[min,rnd,grey]  headstem   32
mirp[rnd,grey]  headstem_plus_hole 38
IUP[x]
SVTCA[y-axis]                       ;Set freedom and projection Vectors To Coordinate Axis
MDAP[rnd]   1
mirp[min,rnd,grey]  vstem   14
mirp[rp0,rnd,grey]  vheight_shoot  25
mirp[min,rnd,grey]  vstem_curve   18
mdrp[rp0,rnd,grey]  4
mirp[min,rnd,grey]  headstem    35
mirp[rp0,rnd,grey]  headdia 10
mirp[min,rnd,grey]  headstem    29
srp1    18
srp2    13
sloop   5
ip  22 21 2 15 28
IUP[y]
""",

    #ho_nokhuk
    "uni0E2E": """
srp0    55
mirp[rp0,min,rnd,grey]  front_dek 1
alignrp     22
mirp[min,rnd,grey]  hstem   12
shp[rp2]    52
mirp[rp0,rnd,grey]  w_864 32
mirp[min,rnd,grey]  hstem 14
mdrp[rp0,rnd,grey]  29
mdrp[rnd,white] 56
srp2    15
sloop 5
ip 47 17 27 30 28
srp0    1
mirp[rp0,rnd,grey]  headdia_plus 7
mirp[min,rnd,grey]  headstem   36
mirp[rnd,grey]  headstem_plus_hole 42
IUP[x]
SVTCA[y-axis]                       ;Set freedom and projection Vectors To Coordinate Axis
MDAP[rnd]   0
mirp[min,rnd,grey]  vstem   14
mirp[rp0,rnd,grey]  vheight_shoot 25
mirp[rnd,grey]  vstem  49
mdrp[rp0,rnd,grey]  19
mdrp[rnd,grey]  45
mdrp[rp0,rnd,white]  4
mirp[min,rnd,grey]  headstem    39
mirp[rp0,rnd,grey]  headdia 10
mirp[min,rnd,grey]  headstem    33
srp1    25
srp2    19
sloop   8
ip  28 27 29 47 30 17 15 32
IUP[y]
""",

    #paiyal
    "uni0E2F": """
srp0    33
mirp[rp0,min,rnd,grey]  front_kai 7
mirp[rp0,rnd,grey]  w_864 20
mirp[min,rnd,grey]  hstem 1
shp[rp2]    19
srp0    7
mirp[min,rnd,grey]  headstem 30
mirp[rp0,rnd,grey]  headdia 13
mirp[min,rnd,grey]  headstem 24
mdrp[min,rnd,grey]  15
IUP[x]
SVTCA[y-axis]
mdap[rnd]   0
mirp[rp0,rnd,grey]  vheight_shoot 19
alignrp 10
mdrp[min,rnd,grey]  2
mdrp[min,rnd,grey]  20
srp0    10
mirp[min,rnd,grey]  headstem 27
mirp[rnd,grey]  headstem_plus_hole 21
mdrp[rp0,rnd,grey]  4
mdrp[min,rnd,grey]  15
IUP[y]
""",

    #sara_a
    "uni0E30": """
srp0    60
mdrp[rp0,min,rnd,grey]  3
alignrp 21
mirp[min,rnd,grey]  headstem 45
mirp[rp0,rnd,grey]  headdia 9
mirp[min,rnd,grey]  headstem 39
mdrp[rp0,rnd,grey]  11
mdrp[rp0,rnd,grey]  14
mdrp[rp0,rnd,grey]  15
mdrp[min,rnd,grey]  61
srp0    21
mirp[min,rnd,grey]  headstem 57
mirp[rp0,rnd,grey]  headdia 27
mirp[min,rnd,grey]  headstem 51
mdrp[rp0,rnd,grey]  29
mdrp[rp0,rnd,grey]  32
mdrp[rp0,rnd,grey]  33
IUP[x]
SVTCA[y-axis]
MDAP[rnd]  0
mdrp[rp0,min,rnd,grey]  11
mdrp[rp0,rnd,grey]  14
mdrp[min,rnd,grey]  15
srp0    0
mdrp[min,rnd,grey]  36
mdrp[rp0,rnd,grey]  6
mirp[min,rnd,grey]  headstem 42
srp0    0
mirp[rp0,rnd,grey]  vheight 24
mirp[min,rnd,grey]  headstem 54
mdrp[rp0,rnd,grey]  18
mdrp[min,rnd,grey]  48
mdrp[rp0,min,rnd,grey]  29
mdrp[rp0,rnd,grey]  32
mdrp[min,rnd,grey]  33
IUP[y]
""",

    #sara_maihanakat
    "uni0E31": """
mdap[rnd]   0
mdrp[rnd,grey]  15
mdrp[rnd,grey]  11
mdrp[rp0,rnd,grey]  3
mirp[min,rnd,grey]  headstem 27
mirp[rp0,rnd,grey]  headdia 9
mirp[min,rnd,grey]  headstem 21
IUP[x]
SVTCA[y-axis]
mdap[rnd]   30
mirp[rp0,min,rnd,grey]  vheight_sara1   0
mirp[rp0,min,rnd,grey]  vstem_small 11
mdrp[rp0,rnd,grey]  14
mirp[min,rnd,grey]  vstem_curve 15
srp0    0
mdrp[min,rnd,grey]  18
mdrp[rp0,rnd,grey]  6
mirp[min,rnd,grey]  headstem 24
IUP[y]
""",

    #sara_aa
    "uni0E32": """
srp0    16
mirp[rp0,min,rnd,grey]  front_khai 8
mirp[rp0,min,rnd,grey]  w_772 15
mdrp[rnd,white] 17
mirp[min,rnd,grey]  hstem 1
IUP[x]
SVTCA[y-axis]
MDAP[rnd]   1
mirp[rp0,rnd,grey]  vheight_shoot 12
mirp[min,rnd,grey]  vstem_curve   5
srp1    5
srp2    1
ip  2
ip  2
IUP[y]
""",

    #sara_am
    #uni0E33: use sara_aa with nikahit
    
    #sara_i
    "uni0E34": """
mdap[rnd]   0
mirp[min,rnd,grey]  w_102 14
mirp[rp0,rnd,white]  w_821 4
mirp[min,rnd,grey]  w_102 20
IUP[x]
SVTCA[y-axis]
mdap[rnd]   22
mirp[rp0,min,rnd,white]  vheight_sara1   0
mdrp[rp0,min,rnd,white]  2
ip 4
mirp[min,rnd,grey]  headstem 12
mirp[rp0,rnd,grey]  w_340 8
mirp[min,rnd,grey]  headstem 17
IUP[y]
""",

    #sara_ii
    "uni0E35": """
mdap[rnd]   0
mirp[min,rnd,grey]  w_102 16
mirp[min,rnd,grey]  sarastem 12
mirp[rp0,rnd,white]  w_821 4
mirp[min,rnd,grey]  w_102 22
IUP[x]
SVTCA[y-axis]
mdap[rnd]   24
mirp[rp0,min,rnd,white]  vheight_sara1   0
mdrp[rp0,min,rnd,white]  2
ip 4
mirp[min,rnd,grey]  headstem 14
mirp[rp0,rnd,grey]  w_340 8
mirp[min,rnd,grey]  headstem 19
mdrp[min,rnd,grey]  12
IUP[y]
""",

    #sara_ue
    "uni0E36": """
mdap[rnd]   0
mirp[min,rnd,grey]  w_102 24
mirp[rp0,rnd,white]  w_821 4
mirp[min,rnd,grey]  w_102 30
srp0    0
mdrp[rp0,rnd,grey]  16
mdrp[min,rnd,grey]  35
mdrp[rp0,rnd,grey]  10
ip 10
ip 19
mdrp[min,rnd,grey]  41
IUP[x]
SVTCA[y-axis]
mdap[rnd]   44
mirp[rp0,min,rnd,white]  vheight_sara1   0
mdrp[rp0,min,rnd,white]  2
ip 4
mirp[min,rnd,grey]  headstem 22
mirp[rp0,rnd,grey]  w_340 8
mirp[min,rnd,grey]  headstem 27
mdrp[min,rnd,grey]  13
mdrp[min,rnd,grey]  38
mdrp[rp0,rnd,grey]  19
ip  10
mdrp[min,rnd,grey]  32
IUP[y]
""",

    #sara_uee
    "uni0E37": """
mdap[rnd]   0
mirp[min,rnd,grey]  w_102 20
mirp[rp0,rnd,white]  w_821 4
mirp[min,rnd,grey]  w_102 26
srp0    0
mirp[rp0,min,rnd,grey] sarastem 16
mirp[rp0,min,rnd,white] w_60 13
mirp[rp0,min,rnd,grey] sarastem 11
IUP[x]
SVTCA[y-axis]
mdap[rnd]   28
mirp[rp0,min,rnd,white]  vheight_sara1   0
mdrp[rp0,min,rnd,white]  2
ip  4
mirp[min,rnd,grey]  headstem 18
mirp[rp0,rnd,grey]  w_340 8
mirp[min,rnd,grey]  headstem 23
sloop 3
ip  10 13 15
mdrp[rp0,min,rnd,grey]  11
alignrp 16
IUP[y]
""",

    #sara_u
    "uni0E38": """
mdap[rnd]   1
mirp[rp0,rnd,grey]  vstem   12
mdrp[min,rnd,grey]  16
mdrp[rp0,rnd,grey]  7
mirp[min,rnd,grey]  headstem_tiny 22
IUP[x]
SVTCA[y-axis]
mdap[rnd]   25
mirp[rp0,min,rnd,grey]  vstem_tiny 10
mirp[min,rnd,grey]  headstem_tiny 19
mdrp[rp0,rnd,grey]  4
mirp[min,rnd,grey]  headstem_tiny 13
mdrp[rnd,grey]  0
IUP[y]
""",

    #sara_uu
    "uni0E39": """
mdap[rnd]   1
mirp[rp0,min,rnd,grey]  vstem   12
mirp[rp0,rnd,grey]  headstem_tiny 14
mirp[min,rnd,grey]  vstem   16
srp0    12
mdrp[min,rnd,grey]  20
mdrp[rp0,rnd,grey]  7
mirp[min,rnd,grey]  headstem_tiny 26
IUP[x]
SVTCA[y-axis]
mdap[rnd]   29
mirp[rp0,min,rnd,grey]  vstem_tiny 10
alignrp 16
mirp[min,rnd,grey]  headstem_tiny 23
mdrp[rp0,rnd,grey]  4
mirp[min,rnd,grey]  headstem_tiny 17
mdrp[rp0,rnd,grey]  1
mirp[min,rnd,grey]  headstem 13
IUP[y]
""",

    #pinthu
    "uni0E3A": """
mdap[rnd]   9
mdrp[rp0,min,rnd,grey]  3
IUP[x]
SVTCA[y-axis]
mdap[rnd]   12
mirp[rp0,min,rnd,grey]  vstem_tiny 6
mdrp[rp0,min,rnd,grey]  0
IUP[y]
""",

    #thai_baht
    "uni0E3F": """
srp0    49
mirp[rp0,min,rnd,grey]  4 4
mirp[min,rnd,grey]  28  35
shp[rp2]    48
mirp[rp0,min,rnd,grey]  46 18
mirp[min,rnd,grey]  25 27
mdrp[min,rnd,grey]  50
mdrp[rp0,rnd,grey]  12
mirp[min,rnd,grey]  28  40
mdrp[rp0,rnd,grey]  44
alignrp 7
alignrp 31
alignrp 22
mirp[rp0,rnd,grey]  headstem 46
alignrp 5
alignrp 33
alignrp 1
IUP[x]
SVTCA[y-axis]
mdap[rnd]   22
alignrp 3
mdrp[min,rnd,grey]  1
mirp[min,rnd,grey]  173 36
shp[rp2]    45
mirp[min,rnd,grey]  149 23
shp[rp2]    32
mirp[rp0,rnd,grey]  129 8
alignrp     4
mdrp[min,rnd,grey]  6
mirp[min,rnd,grey]  149 44
shp[rp2]    48
srp0    36
mirp[min,rnd,white] 149 31
shp[rp2]    35
ip  15
IUP[y]
SVTCA[x-axis]
deltap1 1 52 15
""",

    #sara_e
    "uni0E40": """
srp0    25
mirp[rp0,min,rnd,grey]  front_e 2
mirp[min,rnd,grey]  hstem 4
mirp[rp0,rnd,grey]  headdia_plus 10
mdrp[rnd,white] 26
mirp[min,rnd,grey]  headstem 16
mirp[rnd,grey]  headstem_plus_hole 22
IUP[x]
SVTCA[y-axis]
MDAP[rnd]   25
mirp[min,rnd,grey]  vheight 4
mirp[rp0,rnd,grey]  vheight_lo 0
mirp[min,rnd,grey]  headstem 13
mirp[rp0,rnd,grey]  headdia 7
mirp[min,rnd,grey]  headstem 19
IUP[y]
""",

    #sara_ae
    #use sara_a reference: uni0E40

    #sara_o
    "uni0E42": """
srp0    52
mirp[rp0,rnd,white]  front_khai 6
mdrp[min,rnd,grey]  28
mdrp[rp0,rnd,grey]  2
ip  5
ip  29
mirp[min,rnd,grey]  hstem   31
mirp[rp0,rnd,grey]  headdia_plus 37
mirp[min,rnd,grey]  headstem 43
mirp[rnd,grey]  headstem_plus_hole 49
mdrp[rp0,rnd,grey]  18
mdrp[rnd,white]  53
IUP[x]
SVTCA[y-axis]
mdap[rnd]   52
mirp[rnd,grey]  vheight_lo 0
mirp[rp0,rnd,grey]  vheight_o 10
mirp[min,rnd,grey]  vstem_curve 25
mdrp[rp0,rnd,grey]  17
mirp[min,rnd,grey]  vstem_curve 18
mdrp[rp0,rnd,grey]  20
mirp[min,rnd,grey]  vstem_curve 15
srp0    0
mirp[min,rnd,grey]  headstem   40
mirp[rp0,rnd,grey]  headdia 34
mirp[min,rnd,grey]  headstem   46
srp1    25
srp2    34
sloop   7
ip  7 6 28 5 29 3 31
IUP[y]
""",

    #sara_i_moun
    "uni0E43": """
srp0    63
mirp[rp0,min,rnd,grey] front_khai 19
mdrp[rp0,rnd,grey]  2
mirp[min,rnd,grey]  hstem 30
mirp[rp0,rnd,grey]  headdia_plus 36
mirp[min,rnd,grey]  headstem 42
mirp[rnd,grey]  headstem_plus_hole 48
mdrp[rnd,white]  64
srp0    19
mdrp[min,rnd,grey] 60
mdrp[rp0,rnd,grey] 13
mirp[min,rnd,grey] headstem 54
mdrp[rp0,min,rnd,white] 8
mirp[min,rnd,grey] vstem_curve 25
IUP[x]
SVTCA[y-axis]
MDAP[rnd]   63
mdrp[rnd,grey]  22
mirp[rp0,rnd,grey]  vheight_lo 0
mirp[min,rnd,grey]  headstem 39
mirp[rp0,rnd,grey]  headdia 33
mirp[min,rnd,grey]  headstem 45
srp0    22
mirp[rnd,grey]  headstem 11
mdrp[min,rnd,grey]  57
mdrp[rp0,rnd,grey]  16
mdrp[min,rnd,grey]  51
srp1    11
srp2    33
sloop   6
ip      6 27 5 28 3 30
IUP[y]
""",

    #sara_i_mlai
    "uni0E44": """
srp0    37
mdrp[rp0,rnd,white] 9
mdrp[rp0,rnd,grey]  2
alignrp 15
sloop 4
ip 10 6 13 5
mirp[min,rnd,grey]  hstem 16
mirp[rp0,rnd,grey]  headdia_plus 22
mirp[min,rnd,grey]  headstem 28
mirp[rnd,grey]  headstem_plus_hole 34
mdrp[rnd,white]  38
IUP[x]
SVTCA[y-axis]
MDAP[rnd]   37
mirp[min,rnd,grey]  vheight_o 16
mirp[rp0,rnd,grey]  vheight_lo 0
mirp[min,rnd,grey]  headstem 25
mirp[rp0,rnd,grey]  headdia 19
mirp[min,rnd,grey]  headstem 31
srp0    16
mirp[min,rnd,grey]  vstem_curve 3
srp1    16
srp2    3
sloop   4
ip  10 9 3 5 
IUP[y]
""",

    #lakkhangyao
    "uni0E45": """
srp0    16
mdrp[rp0,rnd,white]  8
mirp[rp0,min,rnd,grey]  w_772 15
mirp[min,rnd,grey]  hstem 1
IUP[x]
SVTCA[y-axis]
MDAP[rnd]   16
mirp[rnd,grey]  vheight_lu 1
mirp[rp0,rnd,grey]  vheight_shoot 12
ip 2
ip 15
mirp[min,rnd,grey]  vstem_curve   5
IUP[y]
""",

    #maiyamok
    "uni0E46": """
srp0    38
mirp[rp0,min,rnd,grey]  front_kai 19
mdrp[min,rnd,grey]  8
mirp[rp0,rnd,grey]  w_864 25
mirp[min,rnd,grey]  hstem 1
srp0    19
mdrp[min,rnd,grey]  35
mdrp[rp0,rnd,grey]  13
mirp[min,rnd,grey]  headstem    29
srp1    8
srp2    1
sloop   6
ip  21 6 22 5 23 4
IUP[x]
SVTCA[y-axis]
MDAP[rnd]   38
mirp[rnd,grey]  vheight_lu 1
mirp[rp0,rnd,grey]  vheight_shoot 21
alignrp 23
ip 2
ip 25
mirp[min,rnd,grey]  vstem_curve   6
shp[rp2]    4
mdrp[rp0,rnd,grey]  22
mirp[min,rnd,grey]  vstem   5
mdrp[rp0,rnd,grey]  10
mirp[min,rnd,grey]  headstem    32
mirp[rp0,rnd,grey]  headdia 16
mirp[min,rnd,grey]  headstem    26
IUP[y]
""",

    #maitaikhu
    "uni0E47": """
srp0    0
mdrp[rp0,min,rnd,grey]  36
mdrp[rp0,min,rnd,grey]  38
mirp[min,rnd,grey]  headstem_wan 56
mdrp[rp0,rnd,grey]  44
mirp[min,rnd,grey]  headstem_wan 50
mdrp[min,rnd,grey]  19
srp0    0
mdrp[rp0,rnd,grey]  8
mdrp[min,rnd,grey]  28
mdrp[rp0,rnd,grey]  26
mirp[min,rnd,grey]  sarastem 11
IUP[x]
SVTCA[y-axis]
MDAP[rnd]   59
mirp[rp0,min,rnd,grey]  vheight_sara1    0
alignrp 8
mdrp[min,rnd,grey]  36
mdrp[min,rnd,grey]  47
mdrp[rp0,rnd,grey]  41
mirp[min,rnd,grey]  headstem_wan 53
srp0    8
mdrp[min,rnd,grey]  28
mdrp[rp0,rnd,grey]  5
mirp[min,rnd,grey]  vstem_tiny 31
mdrp[rp0,rnd,grey]  23
mirp[rp0,rnd,grey]  vstem_tiny 14
mdrp[rp0,rnd,grey]  18
mdrp[min,rnd,grey]  19
IUP[y]
""",

    #maiek
    "uni0E48": """
srp0    0
mirp[min,rnd,grey]  sarastem 2
IUP[x]
SVTCA[y-axis]
MDAP[rnd]   0
mirp[min,rnd,grey]  headdia_tiny 2
IUP[y]
""",

    #maiek
    "uni0E48.low": """
MDAP[rnd]   0
mirp[min,rnd,grey]  vstem_curve 2
IUP[x]
SVTCA[y-axis]
MDAP[rnd]   5
mirp[rp0,min,rnd,grey]  vheight_sara1 0
mirp[min,rnd,grey]  headdia_tiny 2
IUP[y]
""",

    #maitho
    "uni0E49": """
MDAP[rnd]   1
mdrp[rp0,rnd,grey]  8
mdrp[min,rnd,grey]  5
mirp[min,rnd,grey]  headstem_wan 34
mdrp[rp0,rnd,grey]  14
mirp[min,rnd,grey]  headstem_wan 27
mdrp[rp0,rnd,grey]  17
mdrp[rp0,rnd,grey]  21
mdrp[min,rnd,grey]  22
IUP[x]
SVTCA[y-axis]
MDAP[rnd]   1
mirp[min,rnd,grey]  headstem_tiny 17
shp[rp2]    2
mdrp[rp0,rnd,grey]  5
mirp[min,rnd,grey]  headstem_wan 25
mdrp[rp0,rnd,grey]  11
mirp[min,rnd,grey]  headstem_wan 31
srp0    1
mdrp[rp0,rnd,grey]  21
mirp[min,rnd,grey]  vstem 22
IUP[y]
""",

    #maitho
    "uni0E49.low": """
MDAP[rnd]   1
mdrp[rp0,rnd,grey]  8
mdrp[min,rnd,grey]  5
mirp[min,rnd,grey]  headstem_wan 34
mdrp[rp0,rnd,grey]  14
mirp[min,rnd,grey]  headstem_wan 27
mdrp[rp0,rnd,grey]  17
mdrp[rp0,rnd,grey]  21
sloop 4
ip 24 19 20 23
mdrp[min,rnd,grey]  22
IUP[x]
SVTCA[y-axis]
MDAP[rnd]   37
mirp[rp0,min,rnd,grey]  vheight_sara1 1
mirp[min,rnd,grey]  vstem_tiny 17
shp[rp2]    2
mdrp[rp0,rnd,grey]  5
mirp[min,rnd,grey]  headstem_wan 25
mdrp[rp0,rnd,grey]  11
mirp[min,rnd,grey]  headstem_wan 31
srp0    1
mdrp[rp0,rnd,grey]  21
mirp[min,rnd,grey]  vstem 22
IUP[y]
""",

    #maitri
    "uni0E4A": """
mdap[rnd]   1
mdrp[rp0,rnd,grey]  11
mirp[rp0,min,rnd,grey]  vstem_tiny 23
mdrp[min,rnd,grey]  47
mdrp[rp0,rnd,grey]  17
mirp[min,rnd,grey]  headstem_wan 41
srp0    1
mdrp[rp0,rnd,grey]  2
mdrp[min,rnd,grey]  33
mdrp[rp0,rnd,grey]  5
mirp[min,rnd,grey]  vstem_tiny 31
srp0    33
mdrp[rp0,rnd,grey]  35
mdrp[min,rnd,grey]  36
srp1   11
srp2   1
sloop   6
ip  26 9 27 8 28 7
IUP[x]
SVTCA[y-axis]
MDAP[rnd]   1
mdrp[rp0,rnd,grey]  20
mirp[min,rnd,grey]  headstem_wan 38
mdrp[rp0,rnd,grey]  14
mirp[min,rnd,grey]  headstem_wan 44
mdrp[rp0,rnd,grey]   8
mirp[rp0,min,rnd,grey]  headstem_tiny 27
mdrp[rp0,rnd,grey]  26
alignrp 28
mirp[min,rnd,grey]  headstem_tiny 9
shp[rp2]    7
srp0    1
mdrp[rp0,min,rnd,grey]  2
mdrp[rp0,rnd,grey]  33
mdrp[rp0,rnd,grey]  35
mdrp[min,rnd,grey]  36
IUP[y]
""",

    #maitri
    "uni0E4A.low": """
mdap[rnd]   1
mdrp[rp0,rnd,grey]  11
mdrp[rp0,min,rnd,grey]  23
mdrp[min,rnd,grey]  47
mdrp[rp0,rnd,grey]  17
mirp[min,rnd,grey]  headstem_wan 41
srp0    1
mdrp[rp0,rnd,grey]  2  
mdrp[min,rnd,grey]  33
mdrp[rp0,rnd,grey]  5
mdrp[min,rnd,grey]  31
srp0    33
mdrp[rp0,rnd,grey]  35
mdrp[min,rnd,grey]  36
srp1   11
srp2   1
sloop   6
ip  26 9 27 8 28 7
IUP[x]
SVTCA[y-axis]
MDAP[rnd]   50
mirp[rp0,min,rnd,grey]  vheight_sara1   1
mdrp[rp0,rnd,grey]  20
mirp[min,rnd,grey]  headstem_wan 38
mdrp[rp0,rnd,grey]  14
mirp[min,rnd,grey]  headstem_wan 44
mdrp[rp0,rnd,grey]   8
mirp[rp0,min,rnd,grey]  vstem_tiny 27
mdrp[rp0,rnd,grey]  26
alignrp 28
mirp[min,rnd,grey]  vstem_tiny 9
shp[rp2]    7
srp0    1
mdrp[rp0,min,rnd,grey]  2
mdrp[rp0,rnd,grey]  33
mdrp[rp0,rnd,grey]  35
mdrp[min,rnd,grey]  36
IUP[y]
""",

    #maichattawa
    "uni0E4B": """
srp0    0
alignrp 8
mdrp[min,rnd,grey]  10
mirp[rp0,rnd,grey]  sarastem 6
alignrp 2
mdrp[min,rnd,grey]  4
IUP[x]
SVTCA[y-axis]
MDAP[rnd]   0
mdrp[rp0,rnd,grey]  10
alignrp 2
mirp[rp0,rnd,grey]  sarastem 8
alignrp 4
mdrp[min,rnd,grey]  6
IUP[y]
""",

    #maichattawa
    "uni0E4B.low": """
srp0    0
alignrp 8
mdrp[min,rnd,grey]  10
mirp[rp0,rnd,grey]  vstem_curve 6
alignrp 2
mdrp[min,rnd,grey]  4
IUP[x]
SVTCA[y-axis]
MDAP[rnd]   12
mirp[rp0,min,rnd,grey]  vheight_sara1 0
mdrp[rp0,rnd,grey]  10
alignrp 2
mirp[rp0,rnd,grey]  vstem_curve 8
alignrp 4
mdrp[min,rnd,grey]  6
IUP[y]
""",

    #thanthakhat
    "uni0E4C": """
srp0    0
mdrp[rp0,rnd,grey]  3
mdrp[min,rnd,grey]  29
mdrp[rp0,rnd,grey]  17
mdrp[min,rnd,grey]  23
mdrp[rp0,rnd,grey]  15
mdrp[rp0,rnd,grey]  11
mdrp[min,rnd,grey]  10
IUP[x]
SVTCA[y-axis]
MDAP[rnd]   0
mdrp[min,rnd,grey]  20
mdrp[rp0,rnd,grey]  6
mdrp[min,rnd,grey]  26
mdrp[min,rnd,grey]  15
mdrp[rp0,rnd,grey]  10
mdrp[min,rnd,grey]  11
IUP[y]
""",

    #thanthakhat
    "uni0E4C.low": """
srp0    0
mdrp[rp0,rnd,grey]  3
mirp[min,rnd,grey]  headstem_tiny 29
mdrp[rp0,rnd,grey]  17
mirp[min,rnd,grey]  headstem_tiny 23
mdrp[rp0,rnd,grey]  15
mdrp[rp0,rnd,grey]  11
mdrp[min,rnd,grey]  10
IUP[x]
SVTCA[y-axis]
MDAP[rnd]   32
mirp[rp0,min,rnd,grey]  vheight_sara1   0
mirp[min,rnd,grey]  headstem_tiny 20
mdrp[rp0,rnd,grey]  6
mirp[min,rnd,grey]  sarastem 26
shp[rp2]    15
mdrp[rp0,rnd,grey]  10
mdrp[min,rnd,grey]  11
IUP[y]
""",

    #nikhahit
    "uni0E4D": """
MDAP[rnd]   0
mdrp[rp0,rnd,grey]  9
mdrp[min,rnd,grey]  15
mdrp[rp0,rnd,grey]  3
mdrp[min,rnd,grey]  21
IUP[x]
SVTCA[y-axis]
MDAP[rnd]   24
mirp[rp0,min,rnd,grey]  vheight_sara1    0
mdrp[min,rnd,grey]  12
mdrp[rp0,rnd,grey]  6
mdrp[min,rnd,grey]  18
IUP[y]
""",

    #nikhahit
    "uni0E4D.high": """
MDAP[rnd]   0
mdrp[rp0,rnd,grey]  9
mdrp[min,rnd,grey]  15
mdrp[rp0,rnd,grey]  3
mdrp[min,rnd,grey]  21
IUP[x]
SVTCA[y-axis]
MDAP[rnd]   0
mdrp[min,rnd,grey]  12
mdrp[rp0,rnd,grey]  6
mdrp[min,rnd,grey]  18
IUP[y]
""",

    #yamakkan
    "uni0E4E": """
SRP0    0
mdrp[rp0,rnd,grey]  4
mirp[min,rnd,grey]  sarastem 27
mdrp[rp0,rnd,grey]  10
mirp[min,rnd,grey]  sarastem 20
srp0    0
mdrp[rnd,grey]  24
mdrp[rnd,grey]  16
IUP[x]
SVTCA[y-axis]
MDAP[rnd]   31
mirp[rp0,min,rnd,grey]  vheight_sara1    0
mirp[min,rnd,grey]  headstem    29
mdrp[rp0,rnd,grey]  23
mirp[min,rnd,grey]  headstem    25
mdrp[rp0,rnd,grey]  13
mirp[min,rnd,grey]  headstem    18
mdrp[rp0,rnd,grey]  15
mirp[min,rnd,grey]  headstem    16
IUP[y]
""",

    #fongman
    "uni0E4F": """
SRP0    56
mdrp[rp0,min,rnd,grey]  5
mdrp[min,rnd,grey]  29
mdrp[rp0,rnd,grey]  35
mdrp[min,rnd,grey]  53
mdrp[rp0,rnd,grey]  41
mdrp[min,rnd,grey]  47
mdrp[rp0,rnd,grey]  15
mdrp[min,rnd,grey]  23
mdrp[rnd,grey]  57
IUP[x]
SVTCA[y-axis]
MDAP[rnd]   56
mirp[rp0,rnd,grey]  vheight_lo 0
mdrp[min,rnd,grey]  20
mdrp[rp0,rnd,grey]  32
mdrp[min,rnd,grey]  44
mdrp[rp0,rnd,grey]  38
mdrp[min,rnd,grey]  50
mdrp[rp0,rnd,grey]  10
mdrp[min,rnd,grey]  26
IUP[y]
""",

    #thaidigit_zero
    "uni0E50": """
SRP0    24
mirp[rp0,min,rnd,grey]  headhole    3
mirp[min,rnd,grey]  hstem   21
mirp[rp0,rnd,grey]  hwidth_8    9
mirp[min,rnd,grey]  hstem   15
mdrp[rnd,grey]  25
IUP[x]
SVTCA[y-axis]
MDAP[rnd]   24
mirp[rnd,grey]  vheight_lo  0
mirp[rp0,rnd,grey]  vheight_num 6
mirp[min,rnd,grey]  vstem_curve 18
srp0    0
mirp[min,rnd,grey]  vstem_curve 12
IUP[y]
""",

    #thaidigit_one
    "uni0E51": """
SRP0    48
mirp[rp0,min,rnd,grey]  headhole    3
mirp[min,rnd,grey]  hstem   22
mdrp[rp0,min,rnd,grey]  27
mdrp[rnd,grey]  25
mirp[min,rnd,grey]  headstem 45
mdrp[rp0,min,rnd,grey]  33
mirp[min,rnd,grey]  headstem 39
mdrp[rp0,min,rnd,grey]  16
mirp[rp0,min,rnd,grey]  hstem 9
mdrp[rnd,grey]  49
mdrp[rp0,rnd,grey]  12
mdrp[rnd,grey]  13
IUP[x]
SVTCA[y-axis]
MDAP[rnd]   48
mirp[rp0,rnd,grey]  vheight_num 6
mirp[min,rnd,grey]  vstem_curve 19
srp0    48
mirp[rp0,rnd,grey]  vheight_lo  13
mdrp[min,rnd,grey]  12
srp0    48
mirp[rp0,min,rnd,grey]  special_1 0
mirp[min,rnd,grey]  vstem 25
mdrp[min,rnd,grey]  36
mdrp[rp0,rnd,grey]  30
mirp[min,rnd,grey]  headstem 42
IUP[y]
""",

    #thaidigit_two
    "uni0E52": """
SRP0    50
mirp[rp0,min,rnd,grey]  headhole    3
mirp[rp0,min,rnd,grey]  hstem   8
mdrp[rp0,min,rnd,grey]  30
mdrp[rnd,grey]  19
mdrp[min,rnd,grey]  47
mdrp[rp0,min,rnd,grey]  24
mirp[min,rnd,grey]  headstem 41
mdrp[rp0,min,rnd,grey]  13
mirp[rp0,min,rnd,grey]  hstem 36
mdrp[rnd,grey]  51
srp1    3
srp2    8
sloop   4
ip  5 6 1 10
IUP[x]
SVTCA[y-axis]
MDAP[rnd]   0
mirp[min,rnd,grey]  vstem 11
mirp[rp0,rnd,grey]  vheight_num 32
alignrp 34
mirp[min,rnd,grey]  vstem_curve 17
shp[rp2]    15
mdrp[rp0,min,rnd,grey]  33
mirp[rp0,min,rnd,grey]  vstem 16
mdrp[rp0,rnd,grey]  21
mirp[min,rnd,grey]  headstem 44
mirp[rp0,rnd,grey]  headdia 27
mirp[min,rnd,grey]  headstem 38
srp0    0
mdrp[rp0,rnd,grey]  6
mdrp[min,rnd,grey]  5
IUP[y]
""",

    #thaidigit_three
    "uni0E53": """
SRP0    52
mirp[rp0,min,rnd,grey]  headhole    28
mirp[min,rnd,grey]  hstem   16
srp0    28
mdrp[min,rnd,grey]  49
mdrp[rp0,min,rnd,grey]  22
mirp[min,rnd,grey]  headstem 43
mdrp[rp0,rnd,grey]  10
mirp[rp0,min,rnd,grey]  hstem 9
mdrp[rp0,min,rnd,grey]  3
mirp[rp0,min,rnd,grey]  hstem 38
mdrp[rnd,grey]  53
mdrp[rp0,rnd,grey]  0
mirp[min,rnd,grey]  hstem 1
srp1    10
srp2    9
ip  33
IUP[x]
SVTCA[y-axis]
MDAP[rnd]   1
mirp[rnd,grey]  vheight_lo 25
mirp[rp0,rnd,grey]  vheight_num 35
alignrp 31
mirp[min,rnd,grey]  vstem_curve 6
shp[rp2]    13
mdrp[rp0,min,rnd,grey]  33
mdrp[min,rnd,grey]  10
srp0    25
mirp[min,rnd,grey]  headstem 40
mirp[rp0,rnd,grey]  headdia 19
mirp[min,rnd,grey]  headstem 46
mdrp[rnd,grey]  17
IUP[y]
""",

    #thaidigit_four
    "uni0E54": """
SRP0    51
mirp[rp0,min,rnd,grey]  headhole    7
mirp[rp0,min,rnd,grey]  hstem   20
mdrp[rp0,min,rnd,grey]  27
mdrp[min,rnd,grey]  25
mdrp[min,rnd,grey]  48
mdrp[rp0,rnd,grey]  33
mirp[min,rnd,grey]  headstem 42
mdrp[min,rnd,grey]  36
srp0    25
mdrp[rp0,min,rnd,grey]  2
mdrp[rp0,min,rnd,grey]  0
mdrp[rnd,grey]  14
IUP[x]
SVTCA[y-axis]
MDAP[rnd]   51
mirp[rp0,rnd,grey]  special_2 0
alignrp 4
mdrp[rp0,min,rnd,grey]  38
mdrp[rp0,rnd,grey]  36
mdrp[min,rnd,grey]  39
mdrp[rp0,rnd,grey]  30
mirp[min,rnd,grey]  headstem 45
srp0 4
mirp[rp0,min,rnd,grey]  vstem_curve 23
mdrp[rnd,grey]  25
srp0    51
mirp[rp0,rnd,grey]  vheight_num 10
mirp[min,rnd,grey]  vstem_curve 16
mdrp[rp0,rnd,grey]  13
mdrp[min,rnd,grey]  14
IUP[y]
""",

    #thaidigit_five
    "uni0E55": """
SRP0    73
mirp[rp0,min,rnd,grey]  headhole    7
mirp[rp0,min,rnd,grey]  hstem   30
mdrp[rp0,min,rnd,grey]  37
mdrp[min,rnd,grey]  35
mdrp[min,rnd,grey]  58
mdrp[rp0,rnd,grey]  43
mirp[min,rnd,grey]  headstem 52
mdrp[min,rnd,grey]  46
srp0    35
mdrp[rp0,min,rnd,grey]  2
mdrp[rp0,min,rnd,grey]  0
mdrp[rnd,grey]  24
srp0    7
mdrp[rp0,rnd,grey]  10
mdrp[rp0,rnd,grey]  12
mirp[min,rnd,grey]  headstem 70
mirp[rp0,rnd,grey]  headdia 18
mirp[min,rnd,grey]  headstem 64
mdrp[min,rnd,grey]  20
IUP[x]
SVTCA[y-axis]
MDAP[rnd]   73
mirp[rp0,rnd,grey]  special_2 0
alignrp 4
mdrp[rp0,min,rnd,grey]  48
mdrp[rp0,rnd,grey]  46
mdrp[min,rnd,grey]  49
mdrp[rp0,rnd,grey]  40
mirp[min,rnd,grey]  headstem 55
srp0 4
mirp[rp0,min,rnd,grey]  vstem_curve 33
mdrp[rnd,grey]  35
srp0    73
mirp[rp0,rnd,grey]  vheight_num 20
mirp[min,rnd,grey]  vstem_curve 26
mdrp[rp0,rnd,grey]  23
mdrp[min,rnd,grey]  24
srp0    26
mdrp[min,rnd,grey]  61
mdrp[rp0,rnd,grey]  15
mirp[min,rnd,grey]  headstem    67
srp0    61
mdrp[rnd,grey]  10
IUP[y]
""",

    #thaidigit_six
    "uni0E56": """
SRP0    44
mirp[rp0,min,rnd,grey]  special_1 21
mdrp[min,rnd,grey]  22
mdrp[rp0,rnd,grey]  19
mirp[rp0,rnd,grey]  hwidth_10   29
mirp[min,rnd,grey]  hstem   14
mdrp[min,rnd,grey]  45
srp0    19
mdrp[rp0,rnd,grey]  3
mirp[min,rnd,grey]  headstem 41
mirp[rp0,rnd,grey]  headdia 9
mirp[min,rnd,grey]  headstem 35
mdrp[rnd,grey]  11
IUP[x]
SVTCA[y-axis]
MDAP[rnd]   44
mirp[rnd,grey]  vheight_lo 0
mirp[rp0,rnd,grey]  vheight_num 26
mirp[min,rnd,grey]  vstem_curve 17
mdrp[rp0,rnd,grey]  24
mdrp[min,rnd,grey]  19
mdrp[rp0,rnd,grey]  22
mdrp[min,rnd,grey]  21
srp0    0
mirp[min,rnd,grey]  vstem_curve 11
mdrp[min,rnd,grey]  32
mdrp[rp0,rnd,grey]  6
mirp[min,rnd,grey]  headstem 38
IUP[y]
""",

    #thaidigit_seven
    "uni0E57": """
SRP0    61
mirp[rp0,min,rnd,grey]  headhole    28
mirp[min,rnd,grey]  hstem   16
mdrp[min,rnd,grey]  58
mdrp[rp0,rnd,grey]  22
mirp[min,rnd,grey]  headstem 52
mdrp[rp0,rnd,grey]  10
mirp[rp0,min,rnd,grey]  hstem 9
mdrp[rp0,min,rnd,grey]  3
mdrp[min,rnd,grey]  1
mirp[rp0,min,rnd,grey]  hstem 38
mdrp[rnd,grey]  40
mdrp[rp0,min,rnd,grey]  42
mirp[min,rnd,grey]  vstem_curve 46
mdrp[min,rnd,grey]  44
mdrp[rnd,grey]  62
IUP[x]
SVTCA[y-axis]
MDAP[rnd]   1
mirp[rnd,grey]  vheight_lo 25
mirp[rp0,rnd,grey]  vheight_num 35
alignrp 31
mirp[min,rnd,grey]  vstem_curve 6
shp[rp2]    13
mdrp[rp0,min,rnd,grey]  33
mdrp[min,rnd,grey]  10
srp0    25
mirp[min,rnd,grey]  headstem 49
mirp[rp0,rnd,grey]  headdia 19
mirp[min,rnd,grey]  headstem 55
mdrp[rnd,grey]  17
srp0    1
mirp[rp0,min,rnd,grey]  vstem_curve 40
mdrp[rp0,rnd,grey]  44
mdrp[min,rnd,grey]  45
IUP[y]
""",

    #thaidigit_eight
    "uni0E58": """
SRP0    52
mirp[rp0,min,rnd,grey]  headhole    6
mirp[rp0,min,rnd,grey]  hstem   19
mdrp[rp0,min,rnd,grey]  23
mdrp[rp0,min,rnd,grey]  24
mdrp[rp0,min,rnd,grey]  31
mdrp[min,rnd,grey]  28
mirp[min,rnd,grey]  headstem 49
mdrp[rp0,rnd,grey]  37
mdrp[min,rnd,grey]  43
mdrp[min,rnd,grey]  13
srp1    19
srp2    24
sloop   3
ip  22 3 2
IUP[x]
SVTCA[y-axis]
MDAP[rnd]   52
mirp[rp0,rnd,grey]  special_2 3
alignrp 0
mdrp[min,rnd,grey]  22
mdrp[rp0,min,rnd,grey]  2
mdrp[min,rnd,grey]  23
mdrp[min,rnd,grey]  24
srp0    0
mirp[rp0,min,rnd,grey]  vstem_curve 26
mdrp[rnd,grey]  28
srp0    0
mdrp[min,rnd,grey]  40
mdrp[rp0,rnd,grey]  34
mirp[min,rnd,grey]  headstem 46
srp0    0
mirp[rp0,rnd,grey]  vheight_num 9
mirp[min,rnd,grey]  vstem_curve 15
mdrp[rp0,rnd,grey]  12
mdrp[min,rnd,grey]  13
IUP[y]
""",

    #thaidigit_nine
    "uni0E59": """
SRP0    59
mirp[rp0,min,rnd,grey]  headhole    26
mirp[rp0,min,rnd,grey]  hstem   9
mdrp[rp0,min,rnd,grey]  20
mdrp[rp0,min,rnd,grey]  3
mdrp[rp0,min,rnd,grey]  1
mirp[rp0,min,rnd,grey]  hstem 0
mdrp[rp0,rnd,grey]  41
mdrp[rp0,rnd,grey]  40
ip  35
mdrp[rp0,rnd,grey]  38
mdrp[min,rnd,grey]  37
alignrp 60
srp0    20
mirp[min,rnd,grey]  headstem 49
mirp[rp0,rnd,grey]  headdia 14
mirp[min,rnd,grey]  headstem 56
srp1    3
srp2    41
sloop   3
ip  31 45 35
IUP[x]
SVTCA[y-axis]
MDAP[rnd]   1
mirp[rnd,grey]  vheight_lo 23
mirp[rp0,rnd,grey]  vheight_num 33
alignrp 29
mirp[min,rnd,grey]  vstem_curve 43
shp[rp2]    6
mdrp[rp0,rnd,grey]  31
alignrp 35
mdrp[min,rnd,grey]  45
srp0    35
mdrp[rp0,rnd,grey]  37
mdrp[min,rnd,grey]  38
srp0    23
mdrp[min,rnd,grey]  12
mdrp[min,rnd,grey]  47
mdrp[rp0,rnd,grey]  17
mirp[min,rnd,grey]  headstem 53
IUP[y]
""",

#    #angkhankhu
    "uni0E5A": """
SRP0    35
mdrp[rp0,min,rnd,grey]  7
mirp[rp0,rnd,grey]  hwidth_8 1
alignrp 17
mirp[rp0,min,rnd,grey]  hstem 18
mirp[rp0,rnd,grey]  headstem_tiny 20
mirp[rp0,min,rnd,grey]  hstem 22
mdrp[min,rnd,grey]  36
srp0    7
mirp[min,rnd,grey]  headstem 32
mirp[rp0,rnd,grey]  headdia 13
mirp[min,rnd,grey]  headstem 26
mdrp[min,rnd,grey]  15
IUP[x]
SVTCA[y-axis]
MDAP[rnd]   1
alignrp 20
mirp[rp0,rnd,grey]  vheight_shoot 10
alignrp 17
mirp[min,rnd,grey]  headstem 29
mdrp[rp0,rnd,grey]  4
mdrp[min,rnd,grey]  23
mdrp[min,rnd,grey]  15
mdrp[min,rnd,grey]  2
srp1    17
sloop 3
ip 18 21 22
IUP[y]
""",

#    #khomut
    "uni0E5B": """
SRP0    70
mirp[rp0,min,rnd,grey]  headhole    3
mirp[rp0,min,rnd,grey]  hstem   26
mdrp[rp0,min,rnd,grey]  15
mirp[min,rnd,grey]  headstem   67
mdrp[rp0,min,rnd,grey]  9
mdrp[min,rnd,grey]  61
mdrp[min,rnd,grey]  20
mdrp[rp0,min,rnd,grey]  32
mdrp[min,rnd,grey]  33
mdrp[rp0,min,rnd,grey]  55
mdrp[min,rnd,grey]  54
mdrp[rp0,min,rnd,grey]  34
mdrp[rp0,min,rnd,grey]  37
mdrp[min,rnd,grey]  38
mdrp[rp0,min,rnd,grey]  52
mdrp[min,rnd,grey]  51
mdrp[rp0,min,rnd,grey]  39
mdrp[rp0,min,rnd,grey]  42
mdrp[min,rnd,grey]  43
mdrp[rp0,min,rnd,grey]  49
mdrp[rp0,min,rnd,grey]  46
mdrp[min,rnd,grey]  71
IUP[x]
SVTCA[y-axis]
MDAP[rnd]   70
mirp[rp0,rnd,grey]  vheight_lo  0
mirp[rp0,min,rnd,grey]  vstem_curve 29
mdrp[rp0,min,rnd,grey]  12
mirp[min,rnd,grey]  headstem 58
mirp[rp0,rnd,grey]  headdia 18
mdrp[min,rnd,grey]  20
mirp[min,rnd,grey]  headstem 64
mdrp[rp0,min,rnd,grey]  23
mirp[min,rnd,grey]  vstem_curve 6
srp0    0
mdrp[rp0,min,rnd,grey]  55
alignrp     52
alignrp     49
alignrp     45
mdrp[min,rnd,grey]  54
shp[rp2]    51
mdrp[rp0,min,rnd,grey]  32
alignrp 37
alignrp 42
mdrp[rp0,min,rnd,grey]  33
alignrp 38
alignrp 43
srp0    45
mdrp[min,rnd,grey]  46
IUP[y]
""",

    #to_santan.descless
    "uni0E10.descless": """
srp0    59
mdrp[rp0,min,rnd,grey]  19
mdrp[min,rnd,grey]  41
mirp[rp0,rnd,grey]  hwidth_13   44
mirp[min,rnd,grey]  hstem   16
mdrp[min,rnd,grey]  31
mdrp[min,rnd,grey]  60
srp0    16
mdrp[rp0,min,rnd,grey]  12
mdrp[rnd,grey]  13
mdrp[min,rnd,grey]  2
mdrp[min,rnd,grey]  50
mdrp[rp0,rnd,grey]  7
mirp[min,rnd,grey]  headstem    56
srp0    13
mdrp[rp0,min,rnd,grey]  1
mirp[min,rnd,grey]  hstem   0
SVTCA[y-axis]
mdap[rnd]   1
mdrp[min,rnd,grey]  13
mirp[rp0,rnd,grey]  vheight_shoot   23
mirp[min,rnd,grey]  vstem_curve 38
mdrp[rp0,rnd,grey]  30
mirp[min,rnd,grey]  vstem_curve 31
mdrp[rp0,rnd,grey]  28
mirp[min,rnd,grey]  vstem_curve 33
srp1    23
srp2    33
sloop   4
ip  25 26 36 35
srp0    38
mdrp[rp0,rnd,grey]  10
mirp[min,rnd,grey]  headstem    53
mirp[rp0,rnd,grey]  headdia 4
mirp[min,rnd,grey]  headstem 47
srp1    38
srp2    10
sloop   7
ip  20 41 19 42 18 16 44
IUP[y]
""",

#    #CHAR_NAME
#    "uni0EXX": """
#SRP0    0
#
#IUP[x]
#SVTCA[y-axis]
#MDAP[rnd]   0
#
#IUP[y]
#""",


}

if __name__=="__main__":
    if sys.argv[1] == "--all":
        #$0 --all = ENCODE ALL CHARS
        sfd_file = os.path.basename(sys.argv[0]).split('.',1)[0] + '.sfd'
        print "Encoding all character in %s" % (sfd_file)
        dfont.inst_encode_all( sfd_file, pseudo_code_dict, cvt_dict )
    else:
        #$0 uni0E01 > x.txt = PRINT INSTRUCTION CODE OF uni0E01 TO x.txt
        print '\n'.join(dfont.inst_encode( pseudo_code_dict[sys.argv[1]], cvt_dict ))
